Module LYD_PATH_TYPE

Module LYD_PATH_TYPE 

Constants

LYD_PATH_STD
< Generic data path used for logging, node searching (::lyd_find_xpath(), ::lys_find_path()) as well as creating new nodes (::lyd_new_path(), ::lyd_new_path2()).
LYD_PATH_STD_NO_LAST_PRED
< Similar to ::LYD_PATH_STD except there is never a predicate on the last node. While it can be used to search for nodes, do not use it to create new data nodes (lists).

Type Aliases

Type
@brief Types of the different data paths.