Module LYSC_PATH_TYPE

Module LYSC_PATH_TYPE 

Constants

LYSC_PATH_DATA
< Similar to ::LYSC_PATH_LOG except that schema-only nodes (choice, case) are skipped
LYSC_PATH_DATA_PATTERN
< Similar to ::LYSC_PATH_DATA but there are predicates for all list keys added with “%s” where their values should be so that they can be printed there
LYSC_PATH_LOG
< Descriptive path format used in log messages

Type Aliases

Type
@brief Types of the different schema paths.