Module LYS_OUTFORMAT

Module LYS_OUTFORMAT 

Constants

LYS_OUT_TREE
< Tree schema output format
LYS_OUT_UNKNOWN
< unknown format, used as return value in case of error
LYS_OUT_YANG
< YANG schema output format
LYS_OUT_YANG_COMPILED
< YANG schema output format of the compiled schema tree
LYS_OUT_YIN
< YIN schema output format

Type Aliases

Type
@brief Schema output formats accepted by libyang [printer functions](@ref howtoSchemaPrinters).