Module LY_LOG_LEVEL

Module LY_LOG_LEVEL 

Constants

LY_LLDBG
< Print all messages including some development debug messages (be careful, without subsequently calling ::ly_log_dbg_groups() no debug messages will be printed!).
LY_LLERR
< Print only error messages.
LY_LLVRB
< Besides errors and warnings, print some other verbose messages.
LY_LLWRN
< Print error and warning messages, default value.

Type Aliases

Type
@typedef LY_LOG_LEVEL @brief Verbosity levels of the libyang logger.