pub unsafe extern "C" fn ly_ctx_destroy(ctx: *mut ly_ctx)Expand description
@brief Free all internal structures of the specified context.
The function should be used before terminating the application to destroy and free all structures internally used by libyang. If the caller uses multiple contexts, the function should be called for each used context.
All instance data are supposed to be freed before destroying the context using ::lyd_free_all(), for example. Modules (schemas) are destroyed automatically as part of ::ly_ctx_destroy() call.
Note that the data stored by user into the ::lysc_node.priv pointer are kept untouched and the caller is responsible for freeing this private data.
@param[in] ctx Context to destroy.