ly_ctx_get_module

Function ly_ctx_get_module 

pub unsafe extern "C" fn ly_ctx_get_module(
    ctx: *const ly_ctx,
    name: *const c_char,
    revision: *const c_char,
) -> *mut lys_module
@brief Get YANG module of the given name and revision.

@param[in] ctx Context to work in. @param[in] name Name of the YANG module to get. @param[in] revision Requested revision date of the YANG module to get. If not specified, the schema with no revision is returned, if it is present in the context. @return Pointer to the YANG module, NULL if no schema in the context follows the name and revision requirements.