ly_ctx_get_module_implemented

Function ly_ctx_get_module_implemented 

pub unsafe extern "C" fn ly_ctx_get_module_implemented(
    ctx: *const ly_ctx,
    name: *const c_char,
) -> *mut lys_module
@brief Get the (only) implemented YANG module specified by its name.

@param[in] ctx Context where to search. @param[in] name Name of the YANG module to get. @return The only implemented YANG module revision of the given name in the given context. NULL if there is no implemented module of the given name.