ly_ctx_get_module_latest

Function ly_ctx_get_module_latest 

pub unsafe extern "C" fn ly_ctx_get_module_latest(
    ctx: *const ly_ctx,
    name: *const c_char,
) -> *mut lys_module
@brief Get the latest revision of the YANG module specified by its name.

YANG modules with no revision are supposed to be the oldest one.

@param[in] ctx Context where to search. @param[in] name Name of the YANG module to get. @return The latest revision of the specified YANG module in the given context, NULL if no YANG module of the given name is present in the context.