pub unsafe extern "C" fn ly_ctx_get_modules_hash(
ctx: *const ly_ctx,
) -> u32Expand description
@brief Get the hash of all the modules in the context. Since order of the modules is significant, even when 2 contexts have the same modules but loaded in a different order, the hash will differ.
Modules are added into the context in the order they are loaded in, imports following the modules that imported them.
Hash consists of all module names (1), their revisions (2), all enabled features (3), and their imported/implemented state (4).
@param[in] ctx Context to be examined. @return Context modules hash.