ly_ctx_internal_modules_count

Function ly_ctx_internal_modules_count 

pub unsafe extern "C" fn ly_ctx_internal_modules_count(
    ctx: *const ly_ctx,
) -> u32
@brief Learn the number of internal modules of a context. Internal modules is considered one that was loaded during the context creation.

@param[in] ctx libyang context to examine. @return Number of internal modules.