pub unsafe extern "C" fn ly_ctx_load_module(
ctx: *mut ly_ctx,
name: *const c_char,
revision: *const c_char,
features: *mut *const c_char,
) -> *mut lys_moduleExpand description
@brief Try to find the module in the searchpaths of @p ctx and load it into it. If custom missing module callback is set, it is used instead.
The context itself is searched for the requested module first. If @p revision is not specified (the module of the latest revision is requested) and there is implemented revision of the requested module in the context, this implemented revision is returned despite there might be a newer revision. This behavior is cause by the fact that it is not possible to have multiple implemented revisions of the same module in the context.
@param[in] ctx Context to add to. @param[in] name Name of the module to load. @param[in] revision Optional revision date of the module. If not specified, the latest revision is loaded. @param[in] features Optional array of features ended with NULL to be enabled if the module is being implemented. The feature string ‘*’ enables all and array of length 1 with only the terminating NULL explicitly disables all the features. In case the parameter is NULL, the features are untouched - left disabled in newly loaded module or with the current features settings in case the module is already present in the context. @return Found module, NULL if not found or some error occurred.