ly_in_fd

Function ly_in_fd 

pub unsafe extern "C" fn ly_in_fd(in_: *mut ly_in, fd: c_int) -> c_int
@brief Get or reset file descriptor input handler.

@param[in] in Input handler. @param[in] fd Optional value of a new file descriptor for the handler. If -1, only the current file descriptor value is returned. @return Previous value of the file descriptor. Note that caller is responsible for closing the returned file descriptor in case of setting new descriptor @p fd. @return -1 in case of error when setting up the new file descriptor.