ly_in_file

Function ly_in_file 

pub unsafe extern "C" fn ly_in_file(
    in_: *mut ly_in,
    f: *mut FILE,
) -> *mut FILE
@brief Get or reset file stream input handler.

@param[in] in Input handler. @param[in] f Optional new file stream for the handler. If NULL, only the current file stream is returned. @return NULL in case of invalid argument or an error when setting up the new input file, original input handler @p in is untouched in this case. @return Previous file stream of the handler. Note that caller is responsible for closing the returned stream in case of setting new stream @p f.