pub unsafe extern "C" fn ly_in_filepath(
in_: *mut ly_in,
filepath: *const c_char,
len: usize,
) -> *const c_charExpand description
@brief Get or change the filepath of the file where the parser reads the data.
Note that in case of changing the filepath, the current file is closed and a new one is created/opened instead of renaming the previous file. Also note that the previous filepath string is returned only in case of not changing it’s value.
@param[in] in Input handler. @param[in] filepath Optional new filepath for the handler. If and only if NULL, the current filepath string is returned. @param[in] len Optional number of bytes to use from @p filepath. If 0, the @p filepath is considered to be NULL-terminated and the whole string is taken into account. @return Previous filepath string in case the @p filepath argument is NULL. @return NULL if changing filepath succeedes and ((void *)-1) otherwise.