ly_in_read

Function ly_in_read 

pub unsafe extern "C" fn ly_in_read(
    in_: *mut ly_in,
    buf: *mut c_void,
    count: usize,
) -> Type
@brief Read bytes from an input.

Does not count new lines, which is expected from the caller who has better idea about the content of the read data and can better optimize counting.

@param[in] in Input structure. @param[in] buf Destination buffer. @param[in] count Number of bytes to read. @return LY_SUCCESS on success, @return LY_EDENIED on EOF.