ly_log_dbg_groups

Function ly_log_dbg_groups 

pub unsafe extern "C" fn ly_log_dbg_groups(dbg_groups: u32) -> u32
@brief Enable specific debugging messages (independent of log level).

To get the current value, the function must be called twice resetting the level by the received value. Note: does not have any effect on non-debug (Release) builds

@param[in] dbg_groups Bitfield of enabled debug message groups (see @ref dbggroup). @return Previous options bitfield.