ly_log_level

Function ly_log_level 

pub unsafe extern "C" fn ly_log_level(level: Type) -> Type
@brief Set logger verbosity level.

Does not affect the logging callback.

To get the current value, the function must be called twice resetting the level by the received value.

@param[in] level Verbosity level. @return Previous verbosity level.