ly_out_file

Function ly_out_file 

pub unsafe extern "C" fn ly_out_file(
    out: *mut ly_out,
    f: *mut FILE,
) -> *mut FILE
@brief Get or reset file stream printer handler.

@param[in] out Printer handler. @param[in] f Optional new file stream for the handler. If NULL, only the current file stream is returned. @return Previous file stream of the handler. Note that caller is responsible for closing the returned stream in case of setting new stream @p f.