pub unsafe extern "C" fn ly_out_memory(
out: *mut ly_out,
strp: *mut *mut c_char,
size: usize,
) -> *mut c_charExpand description
@brief Get or change memory where the data are dumped.
@param[in] out Printer handler. @param[in] strp Optional new string pointer to store the resulting data, same rules as in ::ly_out_new_memory() are applied. @param[in] size Size of the buffer provided via @p strp. In case it is 0, the buffer for the printed data is newly allocated even if @p strp points to a pointer to an existing buffer. In case the @p strp is NULL, this parameter is ignored. @return Previous dumped data. Note that the caller is responsible to free the data in case of changing string pointer @p strp.