pub unsafe extern "C" fn ly_out_new_memory(
strp: *mut *mut c_char,
size: usize,
out: *mut *mut ly_out,
) -> TypeExpand description
@brief Create printer handler using memory to dump data.
@param[in] strp Pointer to store the resulting data. If it points to a pointer to an allocated buffer and @p size of the buffer is set, the buffer is used (and extended if needed) to store the printed data. @param[in] size Size of the buffer provided via @p strp. In case it is 0, the buffer for the printed data is newly allocated even if @p strp points to a pointer to an existing buffer. @param[out] out Created printer handler supposed to be passed to different ly*_print() functions. @return LY_SUCCESS in case of success @return LY_ERR value in case of failure.