ly_set_clean

Function ly_set_clean 

pub unsafe extern "C" fn ly_set_clean(
    set: *mut ly_set,
    destructor: Option<unsafe extern "C" fn(obj: *mut c_void)>,
)
@brief Remove all objects from the set, but keep the set container for further use.

@param[in] set Set to clean. @param[in] destructor Optional function to free the objects in the set.