ly_set_contains

Function ly_set_contains 

pub unsafe extern "C" fn ly_set_contains(
    set: *const ly_set,
    object: *const c_void,
    index_p: *mut u32,
) -> ly_bool
@brief Learn whether the set contains the specified object.

@param[in] set Set to explore. @param[in] object Object to be found in the set. @param[out] index_p Optional pointer to return index of the searched @p object. @return Boolean value whether the @p object was found in the @p set.