ly_set_free

Function ly_set_free 

pub unsafe extern "C" fn ly_set_free(
    set: *mut ly_set,
    destructor: Option<unsafe extern "C" fn(obj: *mut c_void)>,
)
@brief Free the ::ly_set data. If the destructor is not provided, it frees only the set structure content, not the referred data.

@param[in] set The set to be freed. @param[in] destructor Optional function to free the objects in the set.