ly_set_rm

Function ly_set_rm 

pub unsafe extern "C" fn ly_set_rm(
    set: *mut ly_set,
    object: *mut c_void,
    destructor: Option<unsafe extern "C" fn(obj: *mut c_void)>,
) -> Type
@brief Remove an object from the set.

Note that after removing the object from a set, indexes of other objects in the set can change (the last object is placed instead of the removed object).

@param[in] set Set from which to remove. @param[in] object The object to be removed from the @p set. @param[in] destructor Optional function to free the objects being removed. @return LY_ERR return value.