ly_set_rm_index_ordered

Function ly_set_rm_index_ordered 

pub unsafe extern "C" fn ly_set_rm_index_ordered(
    set: *mut ly_set,
    index: u32,
    destructor: Option<unsafe extern "C" fn(obj: *mut c_void)>,
) -> Type
@brief Remove an object on the specific set index.

Unlike ::ly_set_rm_index(), this function moves all the items following the removed one.

@param[in] set Set from which to remove. @param[in] index Index of the object to remove in the @p set. @param[in] destructor Optional function to free the objects being removed. @return LY_ERR return value.