ly_write

Function ly_write 

pub unsafe extern "C" fn ly_write(
    out: *mut ly_out,
    buf: *const c_char,
    len: usize,
) -> Type
@brief Generic printer of the given string buffer into the specified output.

Alternatively, ::ly_print() can be used.

@param[in] out Output specification. @param[in] buf Memory buffer with the data to print. @param[in] len Length of the data to print in the @p buf. @return LY_ERR value, get number of the printed bytes using ::ly_out_printed.