lyd_change_term

Function lyd_change_term 

pub unsafe extern "C" fn lyd_change_term(
    term: *mut lyd_node,
    val_str: *const c_char,
) -> Type
@brief Change the value of a term (leaf or leaf-list) node to a string value.

Node changed this way is always considered explicitly set, meaning its default flag is always cleared.

@param[in] term Term node to change. @param[in] val_str New value to set, any prefixes are expected in JSON format. @return LY_SUCCESS if value was changed, @return LY_EEXIST if value was the same and only the default flag was cleared, @return LY_ENOT if the values were equal and no change occurred, @return LY_ERR value on other errors.