pub unsafe extern "C" fn lyd_diff_apply_module(
data: *mut *mut lyd_node,
diff: *const lyd_node,
mod_: *const lys_module,
diff_cb: lyd_diff_cb,
cb_data: *mut c_void,
) -> TypeExpand description
@brief Apply the whole diff on a data tree but restrict the operation to one module.
!! Caution !! If applying a diff that was created without the ::LYD_DIFF_DEFAULTS flag, there may be some duplicate values created. Unless the resulting tree is validated (and default values thus consolidated), using it further (such as applying another diff) may cause unexpected results or errors.
@param[in,out] data Data to apply the diff on. @param[in] diff Diff to apply. @param[in] mod Module, whose diff/data only to consider, NULL for all modules. @param[in] diff_cb Optional diff callback that will be called for every changed node. @param[in] cb_data Arbitrary callback data. @return LY_SUCCESS on success, @return LY_ERR on error.