lyd_diff_merge_tree

Function lyd_diff_merge_tree 

pub unsafe extern "C" fn lyd_diff_merge_tree(
    diff_first: *mut *mut lyd_node,
    diff_parent: *mut lyd_node,
    src_sibling: *const lyd_node,
    diff_cb: lyd_diff_cb,
    cb_data: *mut c_void,
    options: u16,
) -> Type
@brief Merge 2 diff trees into each other.

Details are mentioned in ::lyd_diff_merge_module().

@param[in,out] diff_first Target diff first sibling to merge into. @param[in] diff_parent Target diff parent to merge into. @param[in] src_sibling Source diff sibling to merge. @param[in] diff_cb Optional diff callback that will be called for every merged node. Param @p diff_node is the source diff node while @p data_node is the updated target diff node. In case a whole subtree is added, the callback is called on the root with @p diff_node being NULL. @param[in] cb_data Arbitrary callback data. @param[in] options Bitmask of options flags, see @ref diffmergeoptions. @return LY_SUCCESS on success, @return LY_ERR on error.