pub unsafe extern "C" fn lyd_find_path(
ctx_node: *const lyd_node,
path: *const c_char,
output: ly_bool,
match_: *mut *mut lyd_node,
) -> TypeExpand description
@brief Search in given data for a node uniquely identified by a path.
Always works in constant (O(1)) complexity. To be exact, it is O(n) where n is the depth of the path used.
Opaque nodes are NEVER found/traversed.
@param[in] ctx_node Path context node. @param[in] path [Path](@ref howtoXPath) to find. @param[in] output Whether to search in RPC/action output nodes or in input nodes. @param[out] match Can be NULL, otherwise the found data node. @return LY_SUCCESS on success, @p match is set to the found node. @return LY_EINCOMPLETE if only a parent of the node was found, @p match is set to this parent node. @return LY_ENOTFOUND if no nodes in the path were found. @return LY_ERR on other errors.