lyd_find_xpath2

Function lyd_find_xpath2 

pub unsafe extern "C" fn lyd_find_xpath2(
    ctx_node: *const lyd_node,
    xpath: *const c_char,
    vars: *const lyxp_var,
    set: *mut *mut ly_set,
) -> Type
@brief Search in the given data for instances of nodes matching the provided XPath.

It is ::lyd_find_xpath() with @p vars added.

@param[in] ctx_node XPath context node. @param[in] xpath [XPath](@ref howtoXPath) to select in JSON format. @param[in] vars [Sized array](@ref sizedarrays) of XPath variables. @param[out] set Set of found data nodes. In case the result is a number, a string, or a boolean, the returned set is empty. @return LY_SUCCESS on success, @p set is returned. @return LY_ERR value if an error occurred.