lyd_insert_before

Function lyd_insert_before 

pub unsafe extern "C" fn lyd_insert_before(
    sibling: *mut lyd_node,
    node: *mut lyd_node,
) -> Type
@brief Insert a node before another node, can be used only for user-ordered nodes. If inserting several siblings, each of them must be inserted individually.

  • if the node is part of some other tree, it is automatically unlinked.

@param[in] sibling Sibling node to insert before. @param[in] node Node to insert. @return LY_SUCCESS on success. @return LY_ERR error on error.