lyd_insert_child

Function lyd_insert_child 

pub unsafe extern "C" fn lyd_insert_child(
    parent: *mut lyd_node,
    node: *mut lyd_node,
) -> Type
@brief Insert a child into a parent.

  • if the node is part of some other tree, it is automatically unlinked.
  • if the node is the first node of a node list (with no parent), all the subsequent nodes are also inserted.

@param[in] parent Parent node to insert into. @param[in] node Node to insert. @return LY_SUCCESS on success. @return LY_ERR error on error.