lyd_leafref_link_node_tree

Function lyd_leafref_link_node_tree 

pub unsafe extern "C" fn lyd_leafref_link_node_tree(
    tree: *const lyd_node,
) -> Type
@brief Traverse through data tree including root node siblings and adds leafrefs links to the given nodes

This API requires usage of ::LY_CTX_LEAFREF_LINKING context flag.

@param[in] tree The data tree root node. @return LY_SUCCESS on success. @return LY_ERR value on error.