lyd_list_pos

Function lyd_list_pos 

pub unsafe extern "C" fn lyd_list_pos(
    instance: *const lyd_node,
) -> u32
@brief Learn the relative position of a list or leaf-list instance within other instances of the same schema node.

@param[in] instance List or leaf-list instance to get the position of. @return 0 on error. @return Positive integer of the @p instance position.