lyd_new_implicit_all

Function lyd_new_implicit_all 

pub unsafe extern "C" fn lyd_new_implicit_all(
    tree: *mut *mut lyd_node,
    ctx: *const ly_ctx,
    implicit_options: u32,
    diff: *mut *mut lyd_node,
) -> Type
@brief Add any missing implicit nodes. Default nodes with a false “when” are not added.

@param[in,out] tree Tree to add implicit nodes into. Note that in case a first top-level sibling is used, it may no longer be first if an implicit node was inserted before @p tree. Use ::lyd_first_sibling() to adjust @p tree in these cases. @param[in] ctx libyang context, must be set only if @p tree is an empty tree. @param[in] implicit_options Options for implicit node creation, see @ref implicitoptions. @param[out] diff Optional diff with any created nodes. @return LY_ERR value.