lyd_parse_data_mem

Function lyd_parse_data_mem 

pub unsafe extern "C" fn lyd_parse_data_mem(
    ctx: *const ly_ctx,
    data: *const c_char,
    format: Type,
    parse_options: u32,
    validate_options: u32,
    tree: *mut *mut lyd_node,
) -> Type
@brief Parse (and validate) input data as a YANG data tree.

Wrapper around ::lyd_parse_data() hiding work with the input handler and some obscure options.

@param[in] ctx Context to connect with the tree being built here. @param[in] data The input data in the specified @p format to parse (and validate). @param[in] format Format of the input data to be parsed. @param[in] parse_options Options for parser, see @ref dataparseroptions. @param[in] validate_options Options for the validation phase, see @ref datavalidationoptions. @param[out] tree Full parsed data tree, note that NULL can be a valid tree @return LY_SUCCESS in case of successful parsing (and validation). @return LY_ERR value in case of error. Additional error information can be obtained from the context using ly_err* functions.