lyd_parse_opaq_error

Function lyd_parse_opaq_error 

pub unsafe extern "C" fn lyd_parse_opaq_error(
    node: *const lyd_node,
) -> Type
@brief Check node parsed into an opaque node for the reason (error) why it could not be parsed as data node.

The node is expected to be produced by a parser and must either have no parent or a data node parent (not opaque).

@param[in] node Opaque node to check. @return LY_EINVAL if @p node is in some way unexpected (even valid); @return LY_ERR value of the reason.