pub unsafe extern "C" fn lyd_parse_value_fragment(
ctx: *const ly_ctx,
path: *const c_char,
in_: *mut ly_in,
format: Type,
new_val_options: u32,
parse_options: u32,
validate_options: u32,
tree: *mut *mut lyd_node,
) -> TypeExpand description
@brief Parse data from the input handler as a bare JSON value and connect it to the node parsed from the path.
@param[in] ctx Context to connect with the tree being built here. @param[in] path Path to the node so the value in the input handler can be connected to it. @param[in] in Input handler with the value in the JSON format. @param[in] format Currently only LYD_JSON is supported. @param[in] new_val_options Options for new values of the parent node (node to attach the @p in to), see @ref newvaloptions. @param[in] parse_options Options for parser, see @ref dataparseroptions. @param[in] validate_options Options for the validation phase, see @ref datavalidationoptions. @param[out] tree Full parsed data tree, note that NULL can be a valid tree. @return LY_SUCCESS in case of successful parsing. @return LY_ERR value in case of error. Additional error information can be obtained from the context using ly_err* functions.