lyd_validate_all

Function lyd_validate_all 

pub unsafe extern "C" fn lyd_validate_all(
    tree: *mut *mut lyd_node,
    ctx: *const ly_ctx,
    val_opts: u32,
    diff: *mut *mut lyd_node,
) -> Type
@brief Fully validate a data tree.

The data tree is modified in-place. As a result of the validation, some data might be removed from the tree. In that case, the removed items are freed, not just unlinked.

@param[in,out] tree Data tree to recursively validate. May be changed by validation, might become NULL. @param[in] ctx libyang context. Can be NULL if @p tree is set. @param[in] val_opts Validation options (@ref datavalidationoptions). @param[out] diff Optional diff with any changes made by the validation. @return LY_SUCCESS on success. @return LY_ERR error on error.