pub unsafe extern "C" fn lyd_validate_module_final(
tree: *mut lyd_node,
module: *const lys_module,
val_opts: u32,
) -> TypeExpand description
@brief Finish validation of a module data that have previously been validated with ::LYD_VALIDATE_NOT_FINAL flag.
This final validation will not add or remove any nodes.
@param[in] tree Data tree to recursively validate. @param[in] module Module whose data (and schema restrictions) to validate. @param[in] val_opts Validation options (@ref datavalidationoptions). @return LY_SUCCESS on success. @return LY_ERR error on error.