lyd_value_compare

Function lyd_value_compare 

pub unsafe extern "C" fn lyd_value_compare(
    node: *const lyd_node_term,
    value: *const c_char,
    value_len: u32,
) -> Type
@brief Compare the node’s value with the given string value. The string value is first validated according to the (current) node’s type.

@param[in] node Data node to compare. @param[in] value String value to be compared. It does not need to be in a canonical form - as part of the process, it is validated and canonized if possible. But it is expected to be in JSON format. @param[in] value_len Length of the given @p value (mandatory). @return LY_SUCCESS on success, @return LY_ENOT if the values do not match, @return LY_ERR value if an error occurred.