lydict_remove

Function lydict_remove 

pub unsafe extern "C" fn lydict_remove(
    ctx: *const ly_ctx,
    value: *const c_char,
) -> Type
@brief Remove specified string from the dictionary. It decrement reference counter for the string and if it is zero, the string itself is freed.

@param[in] ctx libyang context handler @param[in] value String to be freed. Note, that not only the string itself must match the stored value, but also the address is being compared and the counter is decremented only if it matches. If NULL, function does nothing. @return LY_SUCCESS if the value was found and removed (or refcount decreased). @return LY_ENOTFOUND if the value was not found. @return LY_ERR on other errors.