pub unsafe extern "C" fn lyplg_add(pathname: *const c_char) -> TypeExpand description
@brief Manually load a plugin file.
Note, that a plugin can be loaded only if there is at least one context. The loaded plugins are connected with the existence of a context. When all the contexts are destroyed, all the plugins are unloaded.
@param[in] pathname Path to the plugin file. It can contain types or extensions plugins, both are accepted and correctly loaded.
@return LY_SUCCESS if the file contains valid plugin compatible with the library version. @return LY_EDENIED in case there is no context and the plugin cannot be loaded. @return LY_EINVAL when pathname is NULL or the plugin contains invalid content for this libyang version. @return LY_ESYS when the plugin file cannot be loaded.