lyplg_ext_compile_extension_instance

Function lyplg_ext_compile_extension_instance 

pub unsafe extern "C" fn lyplg_ext_compile_extension_instance(
    ctx: *mut lysc_ctx,
    extp: *const lysp_ext_instance,
    ext: *mut lysc_ext_instance,
    parent: *mut lysc_node,
) -> Type
@brief Compile substatements of an extension instance.

Uses standard libyang schema compiler to transform YANG statements into the compiled schema structures. The plugins are supposed to use this function when the extension instance’s substatements are supposed to be compiled in a standard way (or if just the @ref scflags are enough to modify the compilation process).

@param[in] ctx Compile context. @param[in] extp Parsed representation of the extension instance being processed. @param[in,out] ext Compiled extension instance with the prepared ::lysc_ext_instance.substmts array, which will be updated by storing the compiled data. @param[in] parent Optional parent of all the compiled schema nodes. @return LY_SUCCESS on success. @return LY_EVALID if compilation of the substatements fails. @return LY_ENOT if the extension is disabled (by if-feature) and should be ignored.