pub unsafe extern "C" fn lyplg_ext_schema_mount_create_shared_context(
ext: *mut lysc_ext_instance,
ext_data: *const lyd_node,
) -> TypeExpand description
@brief Create a shared schema mount context for a schema mount point.
Does nothing if the mount point is not shared or if the context already exists.
For printed contexts (read-only), all shared contexts must be created beforehand by calling this function as they cannot be created once the context is printed.
@param[in] ext Compiled extension instance of a schema mount point. @param[in] ext_data ietf-yang-schema-mount and ietf-yang-library YANG data for the @p ext mount point. @return LY_ENOT if @p ext mount point data was not found in @p ext_data, other LY_ERR value otherwise.