lys_parse_mem

Function lys_parse_mem 

pub unsafe extern "C" fn lys_parse_mem(
    ctx: *mut ly_ctx,
    data: *const c_char,
    format: Type,
    module: *mut *mut lys_module,
) -> Type
@brief Load a schema into the specified context.

This function is considered for a simple use, if you have a complex use-case, consider use of ::lys_parse() with a standalone input handler.

@param[in] ctx libyang context to use. @param[in] data String containing the dumped module in the specified format. @param[in] format Format of the schema to parse. @param[out] module Optional parsed module. @return LY_ERR value.