lys_print_path

Function lys_print_path 

pub unsafe extern "C" fn lys_print_path(
    path: *const c_char,
    module: *const lys_module,
    format: Type,
    options: u32,
) -> Type
@brief Print schema tree in the specified format into a file.

This is just a wrapper around ::lys_print_module() for simple use cases. In case of a complex use cases, use lys_print with ly_out output handler.

@param[in] path File where to print the schema. @param[in] module Schema tree to print. @param[in] format Schema output format. @param[in] options Schema output options (see @ref schemaprinterflags). @return LY_ERR value.