lys_set_implemented

Function lys_set_implemented 

pub unsafe extern "C" fn lys_set_implemented(
    mod_: *mut lys_module,
    features: *mut *const c_char,
) -> Type
@brief Make the specific module implemented.

If the module is already implemented but with a different set of features, the whole context is recompiled.

@param[in] mod Module to make implemented. It is not an error to provide already implemented module, it just does nothing. @param[in] features Optional array specifying the enabled features terminated with NULL overriding any previous feature setting. The feature string ‘*’ enables all the features and array of length 1 with only the terminating NULL explicitly disables all the features. In case the parameter is NULL, the features are untouched - left disabled in a newly implemented module or with the current features settings in case the module is already implemented. @return LY_SUCCESS on success. @return LY_EDENIED in case the context contains some other revision of the same module which is already implemented. @return LY_ERR on other errors during module compilation.