pub unsafe extern "C" fn lysc_has_when(
node: *const lysc_node,
) -> *const lysc_whenExpand description
@brief Check whether the schema node data instance existence depends on any when conditions. This node and any direct parent choice and case schema nodes are also examined for when conditions.
Be careful, this function is not recursive and checks only conditions that apply to this node directly. Meaning if there are any conditions associated with any data parent instance of @p node, they are not returned.
@param[in] node Schema node to examine. @return When condition associated with the node data instance, NULL if there is none.