lysc_node_lref_backlinks

Function lysc_node_lref_backlinks 

pub unsafe extern "C" fn lysc_node_lref_backlinks(
    ctx: *const ly_ctx,
    node: *const lysc_node,
    match_ancestors: ly_bool,
    set: *mut *mut ly_set,
) -> Type
@brief Get all the leafref (or union with leafrefs) nodes that target a specific node.

@param[in] ctx Context to use, may not be set if @p node is. @param[in] node Leafref target node to use for matching. If not set, all the leafref nodes are just collected. @param[in] match_ancestors If set, @p node is considered a match not only when a leafref targets it directly but even when an ancestor (parent) node of @p node is a target of the leafref. @param[out] set Set of matching leafref nodes. @return LY_SUCCESS on success. @return LY_ERR value on error.