lysc_node_lref_target

Function lysc_node_lref_target 

pub unsafe extern "C" fn lysc_node_lref_target(
    node: *const lysc_node,
) -> *const lysc_node
@brief Get the target node of a leafref node. Function ::lysc_node_lref_targets() should be used instead to get all the leafref targets even for a union node.

@param[in] node Leafref node. @return Leafref target, NULL on any error.