lysc_node_musts

Function lysc_node_musts 

pub unsafe extern "C" fn lysc_node_musts(
    node: *const lysc_node,
) -> *mut lysc_must
@brief Get the must statements list if present in the @p node

@param[in] node Node to examine. @return Pointer to the list of must restrictions ([sized array](@ref sizedarrays)) @return NULL if there is no must statement in the node, no matter if it is not even allowed or just present