lysc_owner_module

Function lysc_owner_module 

pub unsafe extern "C" fn lysc_owner_module(
    node: *const lysc_node,
) -> *const lys_module
@brief Get the owner module of the schema node. It is the module of the top-level node. Generally, in case of augments it is the target module, recursively, otherwise it is the module where the node is defined.

@param[in] node Schema node to examine. @return Module owner of the node.