pub unsafe extern "C" fn lysc_path(
node: *const lysc_node,
pathtype: Type,
buffer: *mut c_char,
buflen: usize,
) -> *mut c_charExpand description
@brief Generate path of the given node in the requested format.
@param[in] node Schema path of this node will be generated. @param[in] pathtype Format of the path to generate. @param[in,out] buffer Prepared buffer of the @p buflen length to store the generated path. If NULL, memory for the complete path is allocated. @param[in] buflen Size of the provided @p buffer. @return NULL in case of memory allocation error, path of the node otherwise. In case the @p buffer is NULL, the returned string is dynamically allocated and caller is responsible to free it.