lysp_node_child

Function lysp_node_child 

pub unsafe extern "C" fn lysp_node_child(
    node: *const lysp_node,
) -> *const lysp_node
@brief Get the children linked list of the given (parsed) schema node. Decides the node’s type and in case it has a children list, returns it. @param[in] node Node to examine. @return The node’s children linked list if any, NULL otherwise.