pub unsafe extern "C" fn lysp_node_groupings(
node: *const lysp_node,
) -> *const lysp_node_grpExpand description
@brief Get the groupings linked list of the given (parsed) schema node. Decides the node’s type and in case it has a groupings array, returns it. @param[in] node Node to examine. @return The node’s groupings linked list if any, NULL otherwise.