lysp_node_notifs

Function lysp_node_notifs 

pub unsafe extern "C" fn lysp_node_notifs(
    node: *const lysp_node,
) -> *const lysp_node_notif
@brief Get the Notifications linked list of the given (parsed) schema node. Decides the node’s type and in case it has a Notifications array, returns it. @param[in] node Node to examine. @return The node’s Notifications linked list if any, NULL otherwise.