lysp_node_typedefs

Function lysp_node_typedefs 

pub unsafe extern "C" fn lysp_node_typedefs(
    node: *const lysp_node,
) -> *const lysp_tpdf
@brief Get the typedefs sized array of the given (parsed) schema node. Decides the node’s type and in case it has a typedefs array, returns it. @param[in] node Node to examine. @return The node’s typedefs sized array if any, NULL otherwise.