Module lyd_type

Module lyd_type 

Constants

LYD_TYPE_DATA_YANG
< generic YANG instance data
LYD_TYPE_NOTIF_NETCONF
< complete NETCONF notification message as defined for notification
LYD_TYPE_NOTIF_RESTCONF
< RESTCONF JSON notification data (ref), to parse a notification in XML, use ::LYD_TYPE_NOTIF_NETCONF
LYD_TYPE_NOTIF_YANG
< instance of a YANG notification, including all parents in case of a nested one
LYD_TYPE_REPLY_NETCONF
< complete NETCONF RPC reply as defined for RPC and action
LYD_TYPE_REPLY_RESTCONF
< message-body of a RESTCONF operation output parameters (ref)
LYD_TYPE_REPLY_YANG
< instance of a YANG RPC/action reply with only “output” data children, including all parents in case of an action
LYD_TYPE_RPC_NETCONF
< complete NETCONF RPC invocation as defined for RPC and action
LYD_TYPE_RPC_RESTCONF
< message-body of a RESTCONF operation input parameters (ref)
LYD_TYPE_RPC_YANG
< instance of a YANG RPC/action request with only “input” data children, including all parents and optional top-level “action” element in case of an action

Type Aliases

Type
@ingroup datatree @defgroup datatype Data operation type