Type

Type Alias Type 

pub type Type = c_uint;
@ingroup datatree @defgroup datatype Data operation type

Operation provided to ::lyd_validate_op() to validate.

The operation cannot be determined automatically since RPC/action and a reply to it share the common top level node referencing the RPC/action schema node and may not have any input/output children to use for distinction.

@{