#[repr(C)]pub struct ly_err_item {
pub level: Type,
pub err: Type,
pub vecode: Type,
pub msg: *mut c_char,
pub data_path: *mut c_char,
pub schema_path: *mut c_char,
pub line: u64,
pub apptag: *mut c_char,
pub next: *mut ly_err_item,
pub prev: *mut ly_err_item,
}Expand description
@brief Libyang full error structure.
Fields
level: Type< error (message) log level
err: Type< error code number
vecode: Type< validation error code, if any
msg: *mut c_char< error message
data_path: *mut c_char< error data path related to the error, if any
schema_path: *mut c_char< error schema path related to the error, if any
line: u64< input line the error occured on, if available
apptag: *mut c_char< error-app-tag, if any
next: *mut ly_err_item< next error item
prev: *mut ly_err_item< previous error item, points to the last item for the ifrst item