#[repr(C)]pub struct ly_opaq_name {
pub name: *const c_char,
pub prefix: *const c_char,
pub __bindgen_anon_1: ly_opaq_name__bindgen_ty_1,
}Expand description
@brief Generic prefix and namespace mapping, meaning depends on the format.
The union is used as a reference to the data’s module and according to the format, it can be used as a key for ::ly_ctx_get_module_implemented_ns() or ::ly_ctx_get_module_implemented(). While the module reference is always present, the prefix member can be omitted in case it is not present in the source data as a reference to the default module/namespace.
Fields
name: *const c_char< node name, without prefix if any was defined
prefix: *const c_char< identifier used in the qualified name as the prefix, can be NULL
__bindgen_anon_1: ly_opaq_name__bindgen_ty_1Trait Implementations
Sourceimpl Clone for ly_opaq_name
impl Clone for ly_opaq_name
Sourcefn clone(&self) -> ly_opaq_name
fn clone(&self) -> ly_opaq_name
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ly_opaq_name