#[repr(C)]pub struct lyd_leafref_links_rec {
pub node: *const lyd_node_term,
pub leafref_nodes: *mut *const lyd_node_term,
pub target_nodes: *mut *const lyd_node_term,
}Expand description
@brief Structure of leafref links record.
Fields
node: *const lyd_node_termleafref_nodes: *mut *const lyd_node_termpointer to the data node itself
target_nodes: *mut *const lyd_node_termlist of the leafref pointing to this data node [sized array](@ref sizedarrays)), By default it is empty. It is filled automatically by validation function of leafref nodes, which are valid and are not using ‘require-instance false;’. It can also be populated based on manual request using [link api](@ref lyd_leafref_link_node_tree). Freeing of the resources is automatic.