#[repr(C)]pub struct lyd_meta {
pub parent: *mut lyd_node,
pub next: *mut lyd_meta,
pub annotation: *mut lysc_ext_instance,
pub name: *const c_char,
pub value: lyd_value,
}Expand description
@brief Metadata structure.
The structure provides information about metadata of a data element. Such attributes must map to annotations as specified in RFC 7952. The only exception is the filter type (in NETCONF get operations) and edit-config’s operation attributes. In XML, they are represented as standard XML attributes. In JSON, they are represented as JSON elements starting with the ‘@’ character (for more information, see the YANG metadata RFC.
Fields
parent: *mut lyd_node< data node where the metadata is placed
next: *mut lyd_meta< pointer to the next metadata of the same element
annotation: *mut lysc_ext_instance< pointer to the annotation’s definition
name: *const c_char< metadata name
value: lyd_value< metadata value representation