lyd_node_inner__bindgen_ty_1__bindgen_ty_1

Struct lyd_node_inner__bindgen_ty_1__bindgen_ty_1 

#[repr(C)]
pub struct lyd_node_inner__bindgen_ty_1__bindgen_ty_1 { pub hash: u32, pub flags: u32, pub schema: *const lysc_node, pub parent: *mut lyd_node, pub next: *mut lyd_node, pub prev: *mut lyd_node, pub meta: *mut lyd_meta, pub priv_: *mut c_void, }

Fields

hash: u32

< hash of this particular node (module name + schema name + key string values if list or hashes of all nodes of subtree in case of keyless list). Note that while hash can be used to get know that nodes are not equal, it cannot be used to decide that the nodes are equal due to possible collisions.

flags: u32

< [data node flags](@ref dnodeflags)

schema: *const lysc_node

< pointer to the schema definition of this node

parent: *mut lyd_node

< pointer to the parent node, NULL in case of root node

next: *mut lyd_node

< pointer to the next sibling node (NULL if there is no one)

prev: *mut lyd_node

< pointer to the previous sibling node \note Note that this pointer is never NULL. If there is no sibling node, pointer points to the node itself. In case of the first node, this pointer points to the last node in the list.

meta: *mut lyd_meta

< pointer to the list of metadata of this node

priv_: *mut c_void

< private user data, not used by libyang