#[repr(C)]pub struct lyd_node_opaq__bindgen_ty_1__bindgen_ty_1 {
pub hash: u32,
pub flags: u32,
pub schema: *const lysc_node,
pub parent: *mut lyd_node,
pub next: *mut lyd_node,
pub prev: *mut lyd_node,
pub meta: *mut lyd_meta,
pub priv_: *mut c_void,
}Fields
hash: u32< always 0
flags: u32< always 0
schema: *const lysc_node< always NULL
parent: *mut lyd_node< pointer to the parent node, NULL in case of root node
next: *mut lyd_node< pointer to the next sibling node (NULL if there is no one)
prev: *mut lyd_node< pointer to the previous sibling node \note Note that this pointer is never NULL. If there is no sibling node, pointer points to the node itself. In case of the first node, this pointer points to the last node in the list.
meta: *mut lyd_meta< always NULL
priv_: *mut c_void< private user data, not used by libyang