#[repr(C)]pub struct lyd_value_bits {
pub bitmap: *mut c_char,
pub items: *mut *mut lysc_type_bitenum_item,
}Expand description
@brief Special lyd_value structure for built-in bits values.
Fields
bitmap: *mut c_char< bitmap of size ::lyplg_type_bits_bitmap_size(), if its value is cast to an integer type of the corresponding size, can be used directly as a bitmap
items: *mut *mut lysc_type_bitenum_item< list of set pointers to the specification of the set bits ([sized array](@ref sizedarrays))