lysc_ext

Struct lysc_ext 

#[repr(C)]
pub struct lysc_ext { pub name: *const c_char, pub argname: *const c_char, pub exts: *mut lysc_ext_instance, pub plugin_ref: usize, pub module: *mut lys_module, pub flags: u16, }
@brief Compiled YANG extension-stmt

Note that the compiled extension definition is created only in case the extension is instantiated. It is not available from the compiled schema, but from the parsed extension definition which is being searched when an extension instance is being compiled.

Fields

name: *const c_char

< extension name

argname: *const c_char

< argument name, NULL if not specified

exts: *mut lysc_ext_instance

< list of the extension instances ([sized array](@ref sizedarrays))

plugin_ref: usize

< reference to extension plugin, use ::lysc_get_ext_plugin() to get the plugin

module: *mut lys_module

< module structure

flags: u16

< LYS_STATUS_* value (@ref snodeflags)