#[repr(C)]pub struct lysc_ext_instance {
pub def: *mut lysc_ext,
pub argument: *const c_char,
pub module: *mut lys_module,
pub exts: *mut lysc_ext_instance,
pub parent: *mut c_void,
pub parent_stmt: Type,
pub parent_stmt_index: u64,
pub substmts: *mut lysc_ext_substmt,
pub compiled: *mut c_void,
}Expand description
@brief YANG extension compiled instance.
Fields
def: *mut lysc_ext< pointer to the extension definition
argument: *const c_char< optional value of the extension’s argument
module: *mut lys_module< module where the extension instantiated is defined
exts: *mut lysc_ext_instance< list of the extension instances ([sized array](@ref sizedarrays))
parent: *mut c_void< pointer to the parent element holding the extension instance(s), use ::lysc_ext_instance#parent_stmt to access the value/structure
parent_stmt: Type< type of the parent statement
parent_stmt_index: u64< index of the stamenet in case the parent does not point to the parent statement directly and it is an array
substmts: *mut lysc_ext_substmt< list of supported known YANG statements with the pointer to their compiled data ([sized array](@ref sizedarrays))
compiled: *mut c_void< private plugin compiled data