lysc_node_case

Struct lysc_node_case 

#[repr(C)]
pub struct lysc_node_case { pub __bindgen_anon_1: lysc_node_case__bindgen_ty_1, pub child: *mut lysc_node, pub when: *mut *mut lysc_when, }

Fields

__bindgen_anon_1: lysc_node_case__bindgen_ty_1child: *mut lysc_node

< first child node of the case (linked list). Note that all the children of all the sibling cases are linked each other as siblings with the parent pointer pointing to appropriate case node.

when: *mut *mut lysc_when

< list of pointers to when statements ([sized array](@ref sizedarrays))