lysc_node_leaf__bindgen_ty_1__bindgen_ty_1

Struct lysc_node_leaf__bindgen_ty_1__bindgen_ty_1 

#[repr(C)]
pub struct lysc_node_leaf__bindgen_ty_1__bindgen_ty_1 { pub nodetype: u16, pub flags: u16, pub hash: [u8; 4], pub module: *mut lys_module, pub parent: *mut lysc_node, pub next: *mut lysc_node, pub prev: *mut lysc_node, pub name: *const c_char, pub dsc: *const c_char, pub ref_: *const c_char, pub exts: *mut lysc_ext_instance, pub priv_: *mut c_void, }

Fields

nodetype: u16

< LYS_LEAF

flags: u16

< [schema node flags](@ref snodeflags)

hash: [u8; 4]

< schema hash required for LYB printer/parser

module: *mut lys_module

< module structure

parent: *mut lysc_node

< parent node (NULL in case of top level node)

next: *mut lysc_node

< next sibling node (NULL if there is no one)

prev: *mut lysc_node

< pointer to the previous sibling node \note Note that this pointer is never NULL. If there is no sibling node, pointer points to the node itself. In case of the first node, this pointer points to the last node in the list.

name: *const c_char

< node name (mandatory)

dsc: *const c_char

< description

ref_: *const c_char

< reference

exts: *mut lysc_ext_instance

< list of the extension instances ([sized array](@ref sizedarrays))

priv_: *mut c_void

< private arbitrary user data, not used by libyang unless ::LY_CTX_SET_PRIV_PARSED is set