#[repr(C)]pub struct lysc_prefix {
pub prefix: *mut c_char,
pub mod_: *const lys_module,
}Expand description
@brief Compiled prefix data pair mapping of prefixes to modules. In case the format is ::LY_VALUE_SCHEMA_RESOLVED, the expected prefix data is a sized array of these structures.
Fields
prefix: *mut c_char< used prefix
mod_: *const lys_module< mapping to a module