lysp_ext_instance

Struct lysp_ext_instance 

#[repr(C)]
pub struct lysp_ext_instance {
Show 13 fields pub name: *const c_char, pub argument: *const c_char, pub format: Type, pub prefix_data: *mut c_void, pub plugin_ref: usize, pub parent: *mut c_void, pub parent_stmt: Type, pub parent_stmt_index: u64, pub flags: u16, pub substmts: *mut lysp_ext_substmt, pub parsed: *mut c_void, pub child: *mut lysp_stmt, pub exts: *mut lysp_ext_instance,
}
@brief YANG extension parsed instance.

Fields

name: *const c_char

< extension identifier, including possible prefix

argument: *const c_char

< optional value of the extension’s argument

format: Type

< prefix format of the extension name/argument (::LY_VALUE_XML is YIN format)

prefix_data: *mut c_void

< format-specific data for prefix resolution (see ly_resolve_prefix())

plugin_ref: usize

< reference to extension plugin, use ::lysc_get_ext_plugin() to get the plugin

parent: *mut c_void

< pointer to the parent statement holding the extension instance(s), use ::lysp_ext_instance#parent_stmt to access the value/structure

parent_stmt: Type

< type of the parent statement

parent_stmt_index: u64

< index of the stamenet in case the parent does not point to the parent statement directly and it is an array

flags: u16

< ::LYS_INTERNAL value and ::LYS_SINGLEQUOTED or ::LYS_DOUBLEQUOTED describing the argument (@ref snodeflags)

substmts: *mut lysp_ext_substmt

< list of supported known YANG statements with the pointer to their parsed data ([sized array](@ref sizedarrays))

parsed: *mut c_void

< private plugin parsed data

child: *mut lysp_stmt

< list of generic (unknown) YANG statements

exts: *mut lysp_ext_instance

< list of the extension instances ([sized array](@ref sizedarrays))