#[repr(C)]pub struct lysp_import {
pub module: *mut lys_module,
pub name: *const c_char,
pub prefix: *const c_char,
pub dsc: *const c_char,
pub ref_: *const c_char,
pub exts: *mut lysp_ext_instance,
pub flags: u16,
pub rev: [c_char; 11],
}Expand description
@brief YANG import-stmt
Fields
module: *mut lys_module< pointer to the imported module (mandatory, but resolved when the referring module is completely parsed)
name: *const c_char< name of the imported module (mandatory)
prefix: *const c_char< prefix for the data from the imported schema (mandatory)
dsc: *const c_char< description
ref_: *const c_char< reference
exts: *mut lysp_ext_instance< list of the extension instances ([sized array](@ref sizedarrays))
flags: u16< LYS_INTERNAL value (@ref snodeflags)
rev: [c_char; 11]< revision-date of the imported module