lysp_include

Struct lysp_include 

#[repr(C)]
pub struct lysp_include { pub submodule: *mut lysp_submodule, pub name: *const c_char, pub dsc: *const c_char, pub ref_: *const c_char, pub exts: *mut lysp_ext_instance, pub rev: [c_char; 11], pub injected: ly_bool, }
@brief YANG include-stmt

Fields

submodule: *mut lysp_submodule

< pointer to the parsed submodule structure (mandatory, but resolved when the referring module is completely parsed)

name: *const c_char

< name of the included submodule (mandatory)

dsc: *const c_char

< description

ref_: *const c_char

< reference

exts: *mut lysp_ext_instance

< list of the extension instances ([sized array](@ref sizedarrays))

rev: [c_char; 11]

< revision-date of the included submodule

injected: ly_bool

< flag to mark includes copied into main module from submodules, only for backward compatibility with YANG 1.0, which does not require the main module to include all submodules.