#[repr(C)]pub struct lysp_tpdf {
pub name: *const c_char,
pub units: *const c_char,
pub dflt: lysp_qname,
pub dsc: *const c_char,
pub ref_: *const c_char,
pub exts: *mut lysp_ext_instance,
pub type_: lysp_type,
pub flags: u16,
}Expand description
@brief YANG typedef-stmt
Fields
name: *const c_char< name of the newly defined type (mandatory)
units: *const c_char< units of the newly defined type
dflt: lysp_qname< default value of the newly defined type, it may or may not be a qualified name
dsc: *const c_char< description statement
ref_: *const c_char< reference statement
exts: *mut lysp_ext_instance< list of the extension instances ([sized array](@ref sizedarrays))
type_: lysp_type< base type from which the typedef is derived (mandatory)
flags: u16< [schema node flags](@ref spnodeflags)