lysp_type

Struct lysp_type 

#[repr(C)]
pub struct lysp_type {
Show 15 fields pub name: *const c_char, pub range: *mut lysp_restr, pub length: *mut lysp_restr, pub patterns: *mut lysp_restr, pub enums: *mut lysp_type_enum, pub bits: *mut lysp_type_enum, pub path: *mut lyxp_expr, pub bases: *mut *const c_char, pub types: *mut lysp_type, pub exts: *mut lysp_ext_instance, pub pmod: *const lysp_module, pub compiled: *mut lysc_type, pub fraction_digits: u8, pub require_instance: u8, pub flags: u16,
}
@brief YANG type-stmt

Some of the items in the structure may be mandatory, but it is necessary to resolve the type’s base type first

Fields

name: *const c_char

< name of the type (mandatory)

range: *mut lysp_restr

< allowed values range - numerical, decimal64

length: *mut lysp_restr

< allowed length of the value - string, binary

patterns: *mut lysp_restr

< list of patterns ([sized array](@ref sizedarrays)) - string

enums: *mut lysp_type_enum

< list of enum-stmts ([sized array](@ref sizedarrays)) - enum

bits: *mut lysp_type_enum

< list of bit-stmts ([sized array](@ref sizedarrays)) - bits

path: *mut lyxp_expr

< parsed path - leafref

bases: *mut *const c_char

< list of base identifiers ([sized array](@ref sizedarrays)) - identityref

types: *mut lysp_type

< list of sub-types ([sized array](@ref sizedarrays)) - union

exts: *mut lysp_ext_instance

< list of the extension instances ([sized array](@ref sizedarrays))

pmod: *const lysp_module

< (sub)module where the type is defined (needed for deviations)

compiled: *mut lysc_type

< pointer to the compiled custom type, not used for built-in types

fraction_digits: u8

< number of fraction digits - decimal64

require_instance: u8

< require-instance flag - leafref, instance

flags: u16

< [schema node flags](@ref spnodeflags)