lysc_dfs_clb

Type Alias lysc_dfs_clb 

pub type lysc_dfs_clb = Option<unsafe extern "C" fn(node: *mut lysc_node, data: *mut c_void, dfs_continue: *mut ly_bool) -> Type>;
@brief Callback to be called for every schema node in a DFS traversal.

@param[in] node Current node. @param[in] data Arbitrary user data. @param[out] dfs_continue Set to true if the current subtree should be skipped and continue with siblings instead. @return LY_SUCCESS on success, @return LY_ERR value to terminate DFS and return this value.

Aliased Type

pub enum lysc_dfs_clb {
    None,
    Some(unsafe extern "C" fn(*mut lysc_node, *mut c_void, *mut u8) -> u32),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut lysc_node, *mut c_void, *mut u8) -> u32)

Some value of type T.