#[repr(C)]pub union lyd_value__bindgen_ty_1 {
Show 16 fields
pub boolean: i8,
pub dec64: i64,
pub int8: i8,
pub int16: i16,
pub int32: i32,
pub int64: i64,
pub uint8: u8,
pub uint16: u16,
pub uint32: u32,
pub uint64: u64,
pub enum_item: *mut lysc_type_bitenum_item,
pub ident: *mut lysc_ident,
pub target: *mut ly_path,
pub subvalue: *mut lyd_value_union,
pub dyn_mem: *mut c_void,
pub fixed_mem: [u8; 24],
}Fields
boolean: i8< 0 as false, 1 as true
dec64: i64< decimal64: value = dec64 / 10^fraction-digits
int8: i8< 8-bit signed integer
int16: i16< 16-bit signed integer
int32: i32< 32-bit signed integer
int64: i64< 64-bit signed integer
uint8: u8< 8-bit unsigned integer
uint16: u16< 16-bit unsigned integer
uint32: u32< 32-bit unsigned integer
uint64: u64< 64-bit unsigned integer
enum_item: *mut lysc_type_bitenum_item< pointer to the definition of the enumeration value
ident: *mut lysc_ident< pointer to the schema definition of the identityref value
target: *mut ly_path< Instance-identifier target path, use ::lyd_find_target() to evaluate it on data.
subvalue: *mut lyd_value_uniondyn_mem: *mut c_void< pointer to generic data type value stored in dynamic memory
fixed_mem: [u8; 24]< fixed-size buffer for a generic data type value