Skip to main content Crate libyang5_sys Copy item path Source LYD_FORMAT LYD_PATH_TYPE LYPLG LYSC_PATH_TYPE LYS_INFORMAT LYS_OUTFORMAT LYS_VERSION LY_DATA_TYPE LY_ERR LY_IN_TYPE LY_LOG_LEVEL LY_OUT_TYPE LY_VALUE_FORMAT LY_VECODE LY_XPATH_TYPE ly_stmt lyd_type _IO_FILE _IO_codecvt _IO_marker _IO_wide_data __BindgenBitfieldUnit in6_addr in_addr ly_ctx @struct ly_ctx
@brief libyang context handler. ly_err_item @brief Libyang full error structure. ly_ht < hash table with all the direct children (except keys for a list, lists without keys) ly_in @struct ly_in
@brief Parser input structure specifying the type of data input. ly_opaq_name @brief Generic prefix and namespace mapping, meaning depends on the format. ly_out @struct ly_out
@brief Printer output structure specifying the type of data output. ly_path ly_set @brief Structure to hold a set of (not necessary somehow connected) objects. Usually used for lyd_node,
::lysp_node or ::lysc_node objects, but it is not limited to them. Caller is supposed to not mix the type of objects
added to the set and according to its knowledge about the set content, it can access objects via the members
of the set union. lyd_attr @brief Generic attribute structure. lyd_leafref_links_rec @brief Structure of leafref links record. lyd_meta @brief Metadata structure. lyd_node @brief Generic structure for a data node. lyd_node_any @brief Data node structure for the anydata data tree nodes - anydata or anyxml. lyd_node_any__bindgen_ty_1__bindgen_ty_1 lyd_node_inner @brief Data node structure for the inner data tree nodes - containers, lists, RPCs, actions and Notifications. lyd_node_inner__bindgen_ty_1__bindgen_ty_1 lyd_node_opaq @brief Data node structure for unparsed (opaque) nodes. lyd_node_opaq__bindgen_ty_1__bindgen_ty_1 lyd_node_term @brief Data node structure for the terminal data tree nodes - leaves and leaf-lists. lyd_node_term__bindgen_ty_1__bindgen_ty_1 lyd_value @brief YANG data representation lyd_value_binary @brief Special lyd_value structure for built-in binary values. lyd_value_bits @brief Special lyd_value structure for built-in bits values. lyd_value_date @brief Special lyd_value structure for ietf-yang-types date values. lyd_value_date_and_time @brief Special lyd_value structure for ietf-yang-types date-and-time values. lyd_value_date_nz @brief Special lyd_value structure for ietf-yang-types date-no-zone values. lyd_value_ipv4_address @brief Special lyd_value structure for ietf-inet-types ipv4-address values. lyd_value_ipv4_address_no_zone @brief Special lyd_value structure for ietf-inet-types ipv4-address-no-zone values. lyd_value_ipv4_prefix @brief Special lyd_value structure for ietf-inet-types ipv4-prefix values. lyd_value_ipv6_address @brief Special lyd_value structure for ietf-inet-types ipv6-address values. lyd_value_ipv6_address_no_zone @brief Special lyd_value structure for ietf-inet-types ipv6-address-no-zone values. lyd_value_ipv6_prefix @brief Special lyd_value structure for ietf-inet-types ipv6-prefix values. lyd_value_lyds_tree @brief Special lyd_value structure for lyds tree value. lyd_value_time @brief Special lyd_value structure for ietf-yang-types time values. lyd_value_time_nz @brief Special lyd_value structure for ietf-yang-types time-no-zone values. lyd_value_union @brief Special lyd_value structure for built-in union values. lyd_value_xpath10 @brief Special lyd_value structure for ietf-yang-types xpath1.0 values. lyplg_ext @brief Extension plugin implementing various aspects of a YANG extension. lyplg_ext_record lyplg_type lyplg_type_record lys_module @brief Available YANG schema tree structures representing YANG module. lysc_ctx lysc_ext @brief Compiled YANG extension-stmt lysc_ext_instance @brief YANG extension compiled instance. lysc_ext_substmt @brief Structure representing a compiled known YANG substatement in an extension instance. lysc_ident @brief YANG identity-stmt lysc_iffeature @brief Compiled YANG if-feature-stmt lysc_module @brief Compiled YANG schema tree structure representing YANG module. lysc_must lysc_node @brief Compiled YANG data node lysc_node_action lysc_node_action__bindgen_ty_1__bindgen_ty_1 lysc_node_action_inout lysc_node_action_inout__bindgen_ty_1__bindgen_ty_1 lysc_node_anydata lysc_node_anydata__bindgen_ty_1__bindgen_ty_1 lysc_node_case lysc_node_case__bindgen_ty_1__bindgen_ty_1 lysc_node_choice lysc_node_choice__bindgen_ty_1__bindgen_ty_1 lysc_node_container lysc_node_container__bindgen_ty_1__bindgen_ty_1 lysc_node_leaf lysc_node_leaf__bindgen_ty_1__bindgen_ty_1 lysc_node_leaflist lysc_node_leaflist__bindgen_ty_1__bindgen_ty_1 lysc_node_list lysc_node_list__bindgen_ty_1__bindgen_ty_1 lysc_node_notif lysc_node_notif__bindgen_ty_1__bindgen_ty_1 lysc_pattern lysc_prefix @brief Compiled prefix data pair mapping of prefixes to modules. In case the format is ::LY_VALUE_SCHEMA_RESOLVED,
the expected prefix data is a sized array of these structures. lysc_range lysc_range_lysc_range_part lysc_revision @brief Compiled YANG revision statement lysc_submodule @brief Compiled YANG submodule with only some basic metadata required for generating ietf-yang-library data. lysc_type lysc_type_bin lysc_type_bitenum_item lysc_type_bits lysc_type_dec lysc_type_enum lysc_type_identityref lysc_type_instanceid lysc_type_leafref lysc_type_num lysc_type_str lysc_type_union lysc_value lysc_when @brief YANG when-stmt lysp_ctx lysp_deviate @brief Generic deviate structure to get type and cast to lysp_deviate_* structure lysp_deviate_add lysp_deviate_del lysp_deviate_rpl lysp_deviation lysp_ext @brief YANG extension-stmt lysp_ext_instance @brief YANG extension parsed instance. lysp_ext_substmt @brief Structure representing a parsed known YANG substatement in an extension instance. lysp_feature @brief YANG feature-stmt lysp_ident @brief YANG identity-stmt lysp_import @brief YANG import-stmt lysp_include @brief YANG include-stmt lysp_module @brief Printable YANG schema tree structure representing YANG module. lysp_node @brief Generic YANG data node lysp_node_action @brief YANG rpc-stmt and action-stmt lysp_node_action__bindgen_ty_1__bindgen_ty_1 lysp_node_action_inout @brief YANG input-stmt and output-stmt lysp_node_action_inout__bindgen_ty_1__bindgen_ty_1 lysp_node_anydata lysp_node_anydata__bindgen_ty_1__bindgen_ty_1 lysp_node_augment @brief YANG uses-augment-stmt and augment-stmt (compatible with struct lysp_node ) lysp_node_augment__bindgen_ty_1__bindgen_ty_1 lysp_node_case lysp_node_case__bindgen_ty_1__bindgen_ty_1 lysp_node_choice lysp_node_choice__bindgen_ty_1__bindgen_ty_1 lysp_node_container @brief Extension structure of the lysp_node for YANG container lysp_node_container__bindgen_ty_1__bindgen_ty_1 lysp_node_grp @brief YANG grouping-stmt lysp_node_grp__bindgen_ty_1__bindgen_ty_1 lysp_node_leaf lysp_node_leaf__bindgen_ty_1__bindgen_ty_1 lysp_node_leaflist lysp_node_leaflist__bindgen_ty_1__bindgen_ty_1 lysp_node_list lysp_node_list__bindgen_ty_1__bindgen_ty_1 lysp_node_notif @brief YANG notification-stmt lysp_node_notif__bindgen_ty_1__bindgen_ty_1 lysp_node_uses lysp_node_uses__bindgen_ty_1__bindgen_ty_1 lysp_qname @brief Qualified name (optional prefix followed by an identifier). lysp_refine @brief YANG refine-stmt lysp_restr @brief Covers restrictions: range, length, pattern, must lysp_revision @brief YANG revision-stmt lysp_stmt @brief Structure representing a generic parsed YANG substatement in an extension instance. lysp_submodule lysp_tpdf @brief YANG typedef-stmt lysp_type @brief YANG type-stmt lysp_type_enum @brief Enumeration/Bit value definition lysp_when @brief YANG when-stmt lyspr_ctx lyspr_tree_ctx lyxp_expr lyxp_var rb_node timespec LYD_COMPARE_DEFAULTS LYD_COMPARE_FULL_RECURSION LYD_COMPARE_OPAQ LYD_DEFAULT LYD_DIFF_DEFAULTS LYD_DIFF_MERGE_DEFAULTS LYD_DIFF_META LYD_DUP_NO_EXT LYD_DUP_NO_LYDS LYD_DUP_NO_META LYD_DUP_RECURSIVE LYD_DUP_WITH_FLAGS LYD_DUP_WITH_PARENTS LYD_DUP_WITH_PRIV LYD_EXT LYD_HINT_DATA LYD_HINT_SCHEMA LYD_HT_MIN_ITEMS LYD_IMPLICIT_NO_CONFIG LYD_IMPLICIT_NO_DEFAULTS LYD_IMPLICIT_NO_STATE LYD_IMPLICIT_OUTPUT LYD_MERGE_DEFAULTS LYD_MERGE_DESTRUCT LYD_MERGE_WITH_FLAGS LYD_NEW LYD_NEW_ANY_USE_VALUE LYD_NEW_META_CLEAR_DFLT LYD_NEW_PATH_ANY_DATATREE LYD_NEW_PATH_OPAQ LYD_NEW_PATH_UPDATE LYD_NEW_PATH_WITH_OPAQ LYD_NEW_VAL_CANON LYD_NEW_VAL_OUTPUT LYD_NEW_VAL_STORE_ONLY LYD_NODEHINT_CONTAINER LYD_NODEHINT_LEAFLIST LYD_NODEHINT_LIST LYD_NODE_ANY LYD_NODE_INNER LYD_NODE_TERM LYD_PARSE_ANYDATA_STRICT LYD_PARSE_JSON_NULL LYD_PARSE_JSON_STRING_DATATYPES LYD_PARSE_LYB_SKIP_MODULE_CHECK LYD_PARSE_NO_NEW LYD_PARSE_NO_STATE LYD_PARSE_ONLY LYD_PARSE_OPAQ LYD_PARSE_OPTS_MASK LYD_PARSE_ORDERED LYD_PARSE_STORE_ONLY LYD_PARSE_STRICT LYD_PARSE_WHEN_TRUE LYD_PRINT_EMPTY_CONT LYD_PRINT_EMPTY_LEAF_LIST LYD_PRINT_JSON_NO_NESTED_PREFIX LYD_PRINT_SHRINK LYD_PRINT_SIBLINGS LYD_PRINT_WD_ALL LYD_PRINT_WD_ALL_TAG LYD_PRINT_WD_EXPLICIT LYD_PRINT_WD_IMPL_TAG LYD_PRINT_WD_MASK LYD_PRINT_WD_TRIM LYD_VALHINT_BOOLEAN LYD_VALHINT_DECNUM LYD_VALHINT_EMPTY LYD_VALHINT_HEXNUM LYD_VALHINT_NUM64 LYD_VALHINT_OCTNUM LYD_VALHINT_STRING LYD_VALHINT_STRING_DATATYPES LYD_VALIDATE_MULTI_ERROR LYD_VALIDATE_NOT_FINAL LYD_VALIDATE_NO_DEFAULTS LYD_VALIDATE_NO_STATE LYD_VALIDATE_OPERATIONAL LYD_VALIDATE_OPTS_MASK LYD_VALIDATE_PRESENT LYD_VALUE_FIXED_MEM_SIZE LYD_WHEN_TRUE LYPLG_EXT_API_VERSION LYPLG_SUFFIX LYSP_RESTR_PATTERN_ACK LYSP_RESTR_PATTERN_NACK LYS_ACTION LYS_ANYDATA LYS_ANYXML LYS_AUGMENT LYS_CASE LYS_CHOICE LYS_COMPILE_DISABLED LYS_COMPILE_GROUPING LYS_COMPILE_NOTIFICATION LYS_COMPILE_NO_CONFIG LYS_COMPILE_NO_DISABLED LYS_COMPILE_RPC_INPUT LYS_COMPILE_RPC_OUTPUT LYS_CONFIG_MASK LYS_CONFIG_R LYS_CONFIG_W LYS_CONTAINER LYS_DEV_ADD LYS_DEV_DELETE LYS_DEV_NOT_SUPPORTED LYS_DEV_REPLACE LYS_DISABLED LYS_DOUBLEQUOTED LYS_FENABLED LYS_FIND_NO_MATCH_ERROR LYS_FIND_XP_OUTPUT LYS_FIND_XP_SCHEMA LYS_FLAGS_COMPILED_MASK LYS_GETNEXT_INTONPCONT LYS_GETNEXT_NOCHOICE LYS_GETNEXT_OUTPUT LYS_GETNEXT_WITHCASE LYS_GETNEXT_WITHCHOICE LYS_GROUPING LYS_IFF_AND LYS_IFF_F LYS_IFF_NOT LYS_IFF_OR LYS_INPUT LYS_INTERNAL LYS_IS_ENUM LYS_IS_INPUT LYS_IS_NOTIF LYS_IS_OUTPUT LYS_KEY LYS_KEYLESS LYS_LEAF LYS_LEAFLIST LYS_LIST LYS_MAND_FALSE LYS_MAND_MASK LYS_MAND_TRUE LYS_MOD_IMPORTED_REV LYS_MOD_LATEST_IMPCLB LYS_MOD_LATEST_REV LYS_MOD_LATEST_SEARCHDIRS LYS_NODETYPE_MASK LYS_NODE_HASH_COUNT LYS_NOTIF LYS_ORDBY_MASK LYS_ORDBY_SYSTEM LYS_ORDBY_USER LYS_OUTPUT LYS_PRESENCE LYS_PRINT_NO_SUBSTMT LYS_PRINT_SHRINK LYS_RPC LYS_SET_BASE LYS_SET_BIT LYS_SET_CONFIG LYS_SET_DFLT LYS_SET_ENUM LYS_SET_FRDIGITS LYS_SET_LENGTH LYS_SET_MAX LYS_SET_MIN LYS_SET_PATH LYS_SET_PATTERN LYS_SET_RANGE LYS_SET_REQINST LYS_SET_TYPE LYS_SET_UNITS LYS_SET_VALUE LYS_SINGLEQUOTED LYS_STATUS_CURR LYS_STATUS_DEPRC LYS_STATUS_MASK LYS_STATUS_OBSLT LYS_UNIQUE LYS_UNKNOWN LYS_USED_GRP LYS_USES LYS_YINELEM_FALSE LYS_YINELEM_MASK LYS_YINELEM_TRUE LYS_YIN_ARGUMENT LYS_YIN_ATTR LY_CTXP_MEM_ALIGN LY_CTX_ALL_IMPLEMENTED LY_CTX_BUILTIN_PLUGINS_ONLY LY_CTX_COMPILE_OBSOLETE LY_CTX_DISABLE_SEARCHDIRS LY_CTX_DISABLE_SEARCHDIR_CWD LY_CTX_ENABLE_IMP_FEATURES LY_CTX_EXPLICIT_COMPILE LY_CTX_LEAFREF_EXTENDED LY_CTX_LEAFREF_LINKING LY_CTX_LYB_HASHES LY_CTX_NO_YANGLIBRARY LY_CTX_PREFER_SEARCHDIRS LY_CTX_REF_IMPLEMENTED LY_CTX_SET_PRIV_PARSED LY_CTX_STATIC_PLUGINS_ONLY LY_DATA_TYPE_COUNT LY_LDGDEPSETS LY_LDGDICT LY_LDGXPATH LY_LOLOG LY_LOSTORE LY_LOSTORE_LAST LY_PRINT_SHRINK LY_PRI_ARRAY_COUNT_TYPE LY_REV_SIZE LY_STMT_NODE_MASK ly_data_type2str ⚠ @brief Stringfield YANG built-in data types free ⚠ ly_ctx_compile ⚠ @brief Compile (recompile) the context applying all the performed changes after the last context compilation.
Should be used only if ::LY_CTX_EXPLICIT_COMPILE option is set, has no effect otherwise. ly_ctx_compiled_print ⚠ @brief Print (serialize) a compiled context (without any parsed modules) into a pre-allocated memory chunk. ly_ctx_compiled_size ⚠ @brief Get the total size a compiled context requires for serialization. ly_ctx_destroy ⚠ @brief Free all internal structures of the specified context. ly_ctx_free_parsed ⚠ @brief Free all the parsed modules in a context. Any data manipulation will be possible but some schema functionality
will no longer work. ly_ctx_get_change_count ⚠ @brief Get the change count of the context (module set) during its life-time. ly_ctx_get_module ⚠ @brief Get YANG module of the given name and revision. ly_ctx_get_module_imp_clb ⚠ @brief Get the custom callback for missing import/include module retrieval. ly_ctx_get_module_implemented ⚠ @brief Get the (only) implemented YANG module specified by its name. ly_ctx_get_module_implemented_ns ⚠ @brief Get the (only) implemented YANG module specified by its namespace. ly_ctx_get_module_iter ⚠ @brief Iterate over all modules in the given context. ly_ctx_get_module_latest ⚠ @brief Get the latest revision of the YANG module specified by its name. ly_ctx_get_module_latest_ns ⚠ @brief Get the latest revision of the YANG module specified by its namespace. ly_ctx_get_module_ns ⚠ @brief Get YANG module of the given namespace and revision. ly_ctx_get_modules_hash ⚠ @brief Get the hash of all the modules in the context. Since order of the modules is significant,
even when 2 contexts have the same modules but loaded in a different order, the hash will differ. ly_ctx_get_options ⚠ @brief Get the currently set context’s options. ly_ctx_get_searchdirs ⚠ @brief Get the NULL-terminated list of the search paths in libyang context. Do not modify the result! ly_ctx_get_submodule ⚠ @brief Get a specific submodule from context. If its belongs-to module is known, use ::ly_ctx_get_submodule2(). ly_ctx_get_submodule2 ⚠ @brief Get a specific submodule from a module. If the belongs-to module is not known, use ::ly_ctx_get_submodule(). ly_ctx_get_submodule2_latest ⚠ @brief Get the latest revision of a submodule from a module. If the belongs-to module is not known,
use ::ly_ctx_get_submodule_latest(). ly_ctx_get_submodule_latest ⚠ @brief Get the latests revision of a submodule from context. If its belongs-to module is known,
use ::ly_ctx_get_submodule2_latest(). ly_ctx_get_yanglib_data ⚠ @brief Get data of the internal ietf-yang-library module with information about all the loaded modules.
ietf-yang-library module must be loaded. ly_ctx_internal_modules_count ⚠ @brief Learn the number of internal modules of a context. Internal modules
is considered one that was loaded during the context creation. ly_ctx_is_printed ⚠ @brief Check if the context was created from a printed (immutable) context. ly_ctx_load_module ⚠ @brief Try to find the module in the searchpaths of @p ctx and load it into it. If custom missing
module callback is set, it is used instead. ly_ctx_new ⚠ @brief Create libyang context. ly_ctx_new_printed ⚠ @brief Create a (immutable) context that was printed into a memory chunk. ly_ctx_new_yldata ⚠ @brief Create libyang context according to the provided yang-library data in a data tree. ly_ctx_new_ylmem ⚠ @brief Create libyang context according to the provided yang-library data in a string. ly_ctx_new_ylpath ⚠ @brief Create libyang context according to the provided yang-library data in a file. ly_ctx_set_ext_data_clb ⚠ @brief Set callback providing run-time extension instance data. The expected data depend on the extension.
Data expected by internal extensions: ly_ctx_set_module_imp_clb ⚠ @brief Set missing include or import module callback. It is meant to be used when the modules
are not locally available (such as when downloading modules from a NETCONF server), it should
not be required in other cases. ly_ctx_set_options ⚠ @brief Set some of the context’s options, see @ref contextoptions.
@param[in] ctx Context to be modified.
@param[in] option Combination of the context’s options to be set, see @ref contextoptions.
If there is to be a change to ::LY_CTX_SET_PRIV_PARSED, the context will be recompiled
and all ::lysc_node.priv in the modules will be overwritten, see ::LY_CTX_SET_PRIV_PARSED.
@return LY_ERR value. ly_ctx_set_searchdir ⚠ @brief Add the search path into libyang context ly_ctx_unset_options ⚠ @brief Unset some of the context’s options, see @ref contextoptions.
@param[in] ctx Context to be modified.
@param[in] option Combination of the context’s options to be unset, see @ref contextoptions.
@return LY_ERR value. ly_ctx_unset_searchdir ⚠ @brief Clean the search path(s) from the libyang context ly_ctx_unset_searchdir_last ⚠ @brief Remove the least recently added search path(s) from the libyang context. ly_err_clean ⚠ @brief Free error structures from a context. ly_err_first ⚠ @brief Get the first (thread, context-specific) generated error structure. ly_err_last ⚠ @brief Get the latest (thread, context-specific) generated error structure. ly_err_print ⚠ @brief Print the error structure as if just generated. ly_get_log_clb ⚠ @brief Get global logger callback. ly_in_fd ⚠ @brief Get or reset file descriptor input handler. ly_in_file ⚠ @brief Get or reset file stream input handler. ly_in_filepath ⚠ @brief Get or change the filepath of the file where the parser reads the data. ly_in_free ⚠ @brief Free the input handler. ly_in_memory ⚠ @brief Get or change memory where the data are read from. ly_in_new_fd ⚠ @brief Create input handler using file descriptor. ly_in_new_file ⚠ @brief Create input handler using file stream. ly_in_new_filepath ⚠ @brief Create input handler file of the given filename. ly_in_new_memory ⚠ @brief Create input handler using memory to read data. ly_in_parsed ⚠ @brief Get the number of parsed bytes by the last function. ly_in_peek ⚠ @brief Peek at the next byte in an input. ly_in_read ⚠ @brief Read bytes from an input. ly_in_reset ⚠ @brief Reset the input medium to read from its beginning, so the following parser function will read from the object’s beginning. ly_in_skip ⚠ @brief Just skip bytes in an input. ly_in_type ⚠ @brief Get input type of the input handler. ly_last_logmsg ⚠ @brief Get the last (thread-specific) full logged error message. ly_log_dbg_groups ⚠ @brief Enable specific debugging messages (independent of log level). ly_log_level ⚠ @brief Set logger verbosity level. ly_log_options ⚠ @brief Set global logger options. Default is #LY_LOLOG | #LY_LOSTORE_LAST. ly_out_clb ⚠ @brief Get or reset callback function associated with a callback printer handler. ly_out_clb_arg ⚠ @brief Get or reset callback function’s argument associated with a callback printer handler. ly_out_fd ⚠ @brief Get or reset file descriptor printer handler. ly_out_file ⚠ @brief Get or reset file stream printer handler. ly_out_filepath ⚠ @brief Get or change the filepath of the file where the printer prints the data. ly_out_free ⚠ @brief Free the printer handler.
@param[in] out Printer handler to free.
@param[in] clb_arg_destructor Freeing function for printer callback (LY_OUT_CALLBACK) argument.
@param[in] destroy Flag to free allocated buffer (for LY_OUT_MEMORY) or to
close stream/file descriptor (for LY_OUT_FD, LY_OUT_FDSTREAM and LY_OUT_FILE) ly_out_memory ⚠ @brief Get or change memory where the data are dumped. ly_out_new_clb ⚠ @brief Create printer handler using callback printer function. ly_out_new_fd ⚠ @brief Create printer handler using file descriptor. ly_out_new_file ⚠ @brief Create printer handler using file stream. ly_out_new_filepath ⚠ @brief Create printer handler file of the given filename. ly_out_new_memory ⚠ @brief Create printer handler using memory to dump data. ly_out_printed ⚠ @brief Get the number of printed bytes by the last function. ly_out_printed_total ⚠ @brief Get the total number of printed bytes of this out structure. ly_out_reset ⚠ @brief Reset the output medium to write from its beginning, so the following printer function will rewrite the current data
instead of appending. ly_out_type ⚠ @brief Get output type of the printer handler. ly_pattern_compile ⚠ @brief Compile an XML Schema regex pattern prior to matching. ly_pattern_free ⚠ @brief Free a compiled XML Schema regex pattern. ly_pattern_match ⚠ @brief Check a string matches an XML Schema regex used in YANG. ly_print ⚠ @brief Generic printer of the given format string into the specified output. ly_print_flush ⚠ @brief Flush the output from any internal buffers and clean any auxiliary data.
@param[in] out Output specification. ly_realloc ⚠ @brief Wrapper for realloc() call. The only difference is that if it fails to
allocate the requested memory, the original memory is freed as well. ly_set_add ⚠ @brief Add an object into the set ly_set_clean ⚠ @brief Remove all objects from the set, but keep the set container for further use. ly_set_contains ⚠ @brief Learn whether the set contains the specified object. ly_set_dup ⚠ @brief Duplicate the existing set. ly_set_erase ⚠ @brief Alternative to the ::ly_set_free() for static ::ly_set objects - in contrast to ::ly_set_free()
it does not free the provided ::ly_set object. ly_set_free ⚠ @brief Free the ::ly_set data. If the destructor is not provided, it frees only the set structure
content, not the referred data. ly_set_log_clb ⚠ @brief Set global logger callback. ly_set_merge ⚠ @brief Add all objects from @p src to @p trg. ly_set_new ⚠ @brief Create and initiate new ::ly_set structure. ly_set_rm ⚠ @brief Remove an object from the set. ly_set_rm_index ⚠ @brief Remove an object on the specific set index. ly_set_rm_index_ordered ⚠ @brief Remove an object on the specific set index. ly_strerr ⚠ @brief Get human-readable error message for an error code. ly_strvecode ⚠ @brief Get human-readable error message for a validation error code. ly_temp_log_clb ⚠ @brief Set temporary thread-safe (thread-specific) logger callback ovewriting that set by ::ly_set_log_clb. ly_temp_log_options ⚠ @brief Set temporary thread-safe (thread-specific) logger options overwriting those set by ::ly_log_options(). ly_time_str2time ⚠ @brief Convert date-and-time from string to UNIX timestamp and fractions of a second. ly_time_str2ts ⚠ @brief Convert date-and-time from string to timespec. ly_time_time2str ⚠ @brief Convert UNIX timestamp and fractions of a second into canonical date-and-time string value. ly_time_ts2str ⚠ @brief Convert timespec into date-and-time string value. ly_time_tz_offset ⚠ @brief Get current timezone (including DST setting) UTC (GMT) time offset in seconds. ly_time_tz_offset_at ⚠ @brief Get UTC (GMT) timezone offset in seconds at a specific timestamp (including DST setting). ly_write ⚠ @brief Generic printer of the given string buffer into the specified output. lyd_any_copy_value ⚠ @brief Copy anydata value from one node to another. Target value is freed first. lyd_any_value_str ⚠ @brief Get anydata string value. lyd_change_meta ⚠ @brief Change the value of a metadata instance. lyd_change_term ⚠ @brief Change the value of a term (leaf or leaf-list) node to a string value. lyd_change_term_canon ⚠ @brief Change the value of a term (leaf or leaf-list) node to a canonical string value. lyd_child_no_keys ⚠ @brief Get the child pointer of a generic data node but skip its keys in case it is ::LYS_LIST. lyd_compare_meta ⚠ @brief Compare 2 metadata. lyd_compare_siblings ⚠ @brief Compare 2 lists of siblings if they are equivalent. lyd_compare_single ⚠ @brief Compare 2 data nodes if they are equivalent. lyd_diff_apply_all ⚠ @brief Apply the whole diff tree on a data tree. lyd_diff_apply_module ⚠ @brief Apply the whole diff on a data tree but restrict the operation to one module. lyd_diff_merge_all ⚠ @brief Merge 2 diffs into each other. lyd_diff_merge_module ⚠ @brief Merge 2 diffs into each other but restrict the operation to one module. lyd_diff_merge_tree ⚠ @brief Merge 2 diff trees into each other. lyd_diff_reverse_all ⚠ @brief Reverse a diff and make the opposite changes. Meaning change create to delete, delete to create,
or move from place A to B to move from B to A and so on. lyd_diff_siblings ⚠ @brief Learn the differences between 2 data trees including all the following siblings. lyd_diff_tree ⚠ @brief Learn the differences between 2 data trees. lyd_dup_meta_single ⚠ @brief Create a copy of the metadata. lyd_dup_siblings ⚠ @brief Create a copy of the specified data tree @p node with any following siblings. Schema references are kept the same. lyd_dup_siblings_to_ctx ⚠ @brief Create a copy of the specified data tree @p node with any following siblings. Schema references are assigned
from @p trg_ctx. lyd_dup_single ⚠ @brief Create a copy of the specified data tree @p node. Schema references are kept the same. lyd_dup_single_to_ctx ⚠ @brief Create a copy of the specified data tree @p node. Schema references are assigned from @p trg_ctx. lyd_eval_xpath ⚠ @brief Evaluate an XPath on data and return the result converted to boolean. lyd_eval_xpath2 ⚠ @brief Evaluate an XPath on data and return the result converted to boolean. lyd_eval_xpath3 ⚠ @brief Evaluate an XPath on data and return the result converted to boolean. lyd_eval_xpath4 ⚠ @brief Evaluate an XPath on data and return the result or convert it first to an expected result type. lyd_find_meta ⚠ @brief Find a specific metadata. lyd_find_path ⚠ @brief Search in given data for a node uniquely identified by a path. lyd_find_sibling_dup_inst_set ⚠ @brief Search the given siblings for all the exact same instances of a specific node instance.
Uses hashes to whatever extent possible. lyd_find_sibling_first ⚠ @brief Search in the given siblings (NOT recursively) for the first target instance with the same value.
Uses hashes - should be used whenever possible for best performance. lyd_find_sibling_opaq_next ⚠ @brief Search the given siblings for an opaque node with a specific name. lyd_find_sibling_val ⚠ @brief Search in the given siblings for the first schema instance.
Uses hashes - should be used whenever possible for best performance. lyd_find_target ⚠ @brief Find the target node of a compiled path (::lyd_value instance-identifier). lyd_find_xpath ⚠ @brief Search in the given data for instances of nodes matching the provided XPath. lyd_find_xpath2 ⚠ @brief Search in the given data for instances of nodes matching the provided XPath. lyd_find_xpath3 ⚠ @brief Search in the given data for instances of nodes matching the provided XPath. lyd_first_sibling ⚠ @brief Get the first sibling of the given node. lyd_free_all ⚠ @brief Free all the nodes (even parents of the node) in the data tree. lyd_free_attr_siblings ⚠ @brief Free the attribute with any following attributes. lyd_free_attr_single ⚠ @brief Free a single attribute. lyd_free_meta_siblings ⚠ @brief Free the metadata instance with any following instances. lyd_free_meta_single ⚠ @brief Free a single metadata instance. lyd_free_siblings ⚠ @brief Free all the sibling nodes (preceding as well as succeeding). lyd_free_tree ⚠ @brief Free (and unlink) the specified data (sub)tree. lyd_insert_after ⚠ @brief Insert a node after another node, can be used only for user-ordered nodes.
If inserting several siblings, each of them must be inserted individually. lyd_insert_before ⚠ @brief Insert a node before another node, can be used only for user-ordered nodes.
If inserting several siblings, each of them must be inserted individually. lyd_insert_child ⚠ @brief Insert a child into a parent. lyd_insert_sibling ⚠ @brief Insert a node into siblings. lyd_is_default ⚠ @brief Check whether a node value equals to its default one. lyd_leafref_get_links ⚠ @brief Gets the leafref links record for given node lyd_leafref_link_node_tree ⚠ @brief Traverse through data tree including root node siblings and adds leafrefs links to the given nodes lyd_list_pos ⚠ @brief Learn the relative position of a list or leaf-list instance within other instances of the same schema node. lyd_merge_module ⚠ @brief Merge all the nodes of a module from source data tree into the target data tree. Merge may not be
complete until validation called on the resulting data tree (data from more cases may be present, default
and non-default values). lyd_merge_siblings ⚠ @brief Merge the source data tree with any following siblings into the target data tree. Merge may not be
complete until validation called on the resulting data tree (data from more cases may be present, default
and non-default values). lyd_merge_tree ⚠ @brief Merge the source data subtree into the target data tree. Merge may not be complete until validation
is called on the resulting data tree (data from more cases may be present, default and non-default values). lyd_meta_is_internal ⚠ @brief Check whether metadata are not an instance of internal metadata. lyd_metadata_should_print ⚠ @brief Check whether the metadata should be printed. lyd_new_any ⚠ @brief Create a new any node in the data tree. lyd_new_attr ⚠ @brief Create new JSON attribute for an opaque data node. To create an XML attribute, use ::lyd_new_attr2(). lyd_new_attr2 ⚠ @brief Create new XML attribute for an opaque data node. To create a JSON attribute, use ::lyd_new_attr(). lyd_new_implicit_all ⚠ @brief Add any missing implicit nodes. Default nodes with a false “when” are not added. lyd_new_implicit_module ⚠ @brief Add any missing implicit nodes of one module. Default nodes with a false “when” are not added. lyd_new_implicit_tree ⚠ @brief Add any missing implicit nodes into a data subtree. Default nodes with a false “when” are not added. lyd_new_inner ⚠ @brief Create a new inner node in the data tree. lyd_new_list ⚠ @brief Create a new list node in the data tree. lyd_new_list2 ⚠ @brief Create a new list node in the data tree. lyd_new_list3 ⚠ @brief Create a new list node in the data tree. lyd_new_meta ⚠ @brief Create a new metadata. lyd_new_meta2 ⚠ @brief Create new metadata from an opaque node attribute if possible. lyd_new_opaq ⚠ @brief Create a new JSON opaque node in the data tree. To create an XML opaque node, use ::lyd_new_opaq2(). lyd_new_opaq2 ⚠ @brief Create a new XML opaque node in the data tree. To create a JSON opaque node, use ::lyd_new_opaq(). lyd_new_path ⚠ @brief Create a new node in the data tree based on a path. If creating anyxml/anydata nodes, ::lyd_new_path2
should be used instead, this function expects the value as string. lyd_new_path2 ⚠ @brief Create a new node in the data tree based on a path. All node types can be created. lyd_new_term ⚠ @brief Create a new term node in the data tree. lyd_node_module ⚠ @brief Get the module of a node. Useful mainly for opaque nodes. lyd_node_schema ⚠ @brief Get schema node of a data node. Useful especially for opaque nodes. lyd_node_should_print ⚠ @brief Check whether the node should be printed based on the printing options. lyd_owner_module ⚠ @brief Get the owner module of the data node. It is the module of the top-level schema node. Generally,
in case of augments it is the target module, recursively, otherwise it is the module where the data node is defined. lyd_parse_data ⚠ @brief Parse (and validate) data from the input handler as a YANG data tree. lyd_parse_data_fd ⚠ @brief Parse (and validate) input data as a YANG data tree. lyd_parse_data_mem ⚠ @brief Parse (and validate) input data as a YANG data tree. lyd_parse_data_path ⚠ @brief Parse (and validate) input data as a YANG data tree. lyd_parse_op ⚠ @brief Parse YANG data into an operation data tree. Specific parsing flags ::LYD_PARSE_ONLY, ::LYD_PARSE_STRICT and
no validation flags are used. lyd_parse_opaq_error ⚠ @brief Check node parsed into an opaque node for the reason (error) why it could not be parsed as data node. lyd_parse_value_fragment ⚠ @brief Parse data from the input handler as a bare JSON value and connect it to the node parsed from the path. lyd_path ⚠ @brief Generate path of the given node in the requested format. lyd_print_all ⚠ @brief Print the whole data tree of the root, including all the siblings. lyd_print_clb ⚠ @brief Print data tree in the specified format. lyd_print_fd ⚠ @brief Print data tree in the specified format. lyd_print_file ⚠ @brief Print data tree in the specified format. lyd_print_mem ⚠ @brief Print data tree in the specified format. lyd_print_path ⚠ @brief Print data tree in the specified format. lyd_print_tree ⚠ @brief Print the selected data subtree. lyd_trim_xpath ⚠ @brief Evaluate an XPath on data and free all the nodes except the subtrees selected by the expression. lyd_unlink_siblings ⚠ @brief Unlink the specified node with all the following siblings. lyd_unlink_tree ⚠ @brief Unlink the specified data subtree. lyd_validate_all ⚠ @brief Fully validate a data tree. lyd_validate_ext ⚠ @brief Validate a data subtree of an extension instance, which is assumed to be a separate data tree independent of
normal YANG data. lyd_validate_module ⚠ @brief Fully validate a data tree of a module. lyd_validate_module_final ⚠ @brief Finish validation of a module data that have previously been validated with ::LYD_VALIDATE_NOT_FINAL flag. lyd_validate_op ⚠ @brief Validate an RPC/action request, reply, or notification. Only the operation data tree (input/output/notif)
is validate, any parents are ignored. lyd_value_compare ⚠ @brief Compare the node’s value with the given string value. The string value is first validated according to
the (current) node’s type. lyd_value_get_canonical ⚠ @brief Get the (canonical) value of a lyd_value. lyd_value_validate ⚠ @brief Check type restrictions applicable to the particular leaf/leaf-list with the given string @p value. lyd_value_validate_dflt ⚠ @brief Check type restrictions applicable to the particular leaf/leaf-list with the given string @p value. lydict_dup ⚠ @brief Duplicate string in dictionary. Only a reference counter is incremented. lydict_insert ⚠ @brief Insert string into dictionary. If the string is already present,
only a reference counter is incremented and no memory allocation is
performed. lydict_insert_zc ⚠ @brief Insert string into dictionary - zerocopy version. If the string is
already present, only a reference counter is incremented and no memory
allocation is performed. This insert function variant avoids duplication of
specified value - it is inserted into the dictionary directly. lydict_remove ⚠ @brief Remove specified string from the dictionary. It decrement reference
counter for the string and if it is zero, the string itself is freed. lyplg_add ⚠ @brief Manually load a plugin file. lyplg_add_extension_plugin ⚠ @brief Manually load extension plugins from memory lyplg_add_type_plugin ⚠ @brief Manually load type plugins from memory lyplg_ext_cfree_instance_substatements ⚠ @brief Free the extension instance’s data compiled with ::lyplg_ext_compile_extension_instance(). lyplg_ext_compile_extension_instance ⚠ @brief Compile substatements of an extension instance. lyplg_ext_compile_get_ctx ⚠ @brief YANG schema compilation context getter for libyang context. lyplg_ext_compile_get_cur_mod ⚠ @brief YANG schema compilation context getter for current module. lyplg_ext_compile_get_options ⚠ @brief YANG schema compilation context getter for compilation options. lyplg_ext_compile_get_pmod ⚠ @brief YANG schema compilation context getter for currently processed module. lyplg_ext_compile_log ⚠ @brief Log a message from an extension plugin using the compiled extension instance. lyplg_ext_compile_log_err ⚠ @brief Log a message from an extension plugin using the compiled extension instance and a generated error item. lyplg_ext_compile_log_path ⚠ @brief Log a message from an extension plugin using the compiled extension instance with an explicit error path. lyplg_ext_compiled_node_augments ⚠ @brief Compile augments for a specific node in an extension instance. lyplg_ext_compiled_print_add_addr ⚠ @brief Add a printed address of a shared structure to be reused by later prints. lyplg_ext_compiled_print_get_addr ⚠ @brief Get the printed address of a shared structure, in case it has already been printed. lyplg_ext_compiled_stmts_storage_print ⚠ @brief Print the substatements array storage and assign it to the serialized extension instance substatements array. lyplg_ext_compiled_stmts_storage_size ⚠ @brief Get the size of the compiled substatements storage. lyplg_ext_get_data ⚠ @brief Get specific run-time extension instance data from a callback set by ::ly_ctx_set_ext_data_clb(). lyplg_ext_get_storage ⚠ @brief Get compiled ext instance storage for a specific statement. lyplg_ext_nodetype2stmt ⚠ @brief Convert nodetype to statement identifier lyplg_ext_parse_extension_instance ⚠ @brief Parse substatements of an extension instance. lyplg_ext_parse_get_cur_pmod ⚠ @brief Get current parsed module from a parse context. lyplg_ext_parse_log ⚠ @brief Log a message from an extension plugin using the parsed extension instance. lyplg_ext_parsed_get_storage ⚠ @brief Get parsed ext instance storage for a specific statement. lyplg_ext_pfree_instance_substatements ⚠ @brief Free the extension instance’s data parsed with ::lyplg_ext_parse_extension_instance(). lyplg_ext_print_get_level ⚠ @brief YANG printer context getter for printer indentation level. lyplg_ext_print_get_options ⚠ @brief YANG printer context getter for printer options. lyplg_ext_print_get_out ⚠ @brief YANG printer context getter for output handler. lyplg_ext_print_info_extension_instance ⚠ @brief Print substatements of an extension instance in info format (compiled YANG). lyplg_ext_schema_mount_create_context ⚠ @brief Allocate a new context for a particular instance of the yangmnt:mount-point extension.
Caller is responsible for freeing the created context. lyplg_ext_schema_mount_create_shared_context ⚠ @brief Create a shared schema mount context for a schema mount point. lyplg_ext_schema_mount_destroy_inline_contexts ⚠ @brief Destroy all the inline contexts for a given libyang context. lyplg_ext_schema_mount_destroy_shared_contexts ⚠ @brief Destroy all the shared schema mount contexts for a given libyang context. lyplg_ext_schema_mount_get_parent_ref ⚠ @brief Expand parent-reference xpath expressions lyplg_ext_set_parent_ctx ⚠ @brief Set parent context of a context. Errors and callbacks of the parent context will then always be used. lyplg_ext_stmt2str ⚠ @brief Stringify statement identifier. lys_feature_value ⚠ @brief Get the current real status of the specified feature in the module. lys_find_child ⚠ @brief Get a child node according to the specified criteria. lys_find_expr_atoms ⚠ @brief Get all the schema nodes that are required for @p expr to be evaluated (atoms). lys_find_lypath_atoms ⚠ @brief Get all the schema nodes that are required for @p path to be evaluated (atoms). lys_find_module ⚠ @brief Find a module matching a prefix (or a default one). lys_find_path ⚠ @brief Get a schema node based on the given data path (JSON format, see @ref howtoXPath). lys_find_path_atoms ⚠ @brief Get all the schema nodes that are required for @p path to be evaluated (atoms). lys_find_xpath ⚠ @brief Evaluate an @p xpath expression on schema nodes. lys_find_xpath_atoms ⚠ @brief Get all the schema nodes that are required for @p xpath to be evaluated (atoms). lys_getnext ⚠ @brief Get next schema (sibling) node element in the schema order that can be instantiated in a data tree.
Returned node may be from an augment. lys_identity_iffeature_value ⚠ @brief Get how the if-feature statement is evaluated for certain identity. lys_nodetype2str ⚠ @brief Stringify schema nodetype. lys_parse ⚠ @brief Load a schema into the specified context. lys_parse_fd ⚠ @brief Read a schema from file descriptor into the specified context. lys_parse_mem ⚠ @brief Load a schema into the specified context. lys_parse_path ⚠ @brief Load a schema into the specified context from a file. lys_print_clb ⚠ @brief Print schema tree in the specified format using a provided callback. lys_print_fd ⚠ @brief Print schema tree in the specified format into a file descriptor. lys_print_file ⚠ @brief Print schema tree in the specified format into a file stream. lys_print_mem ⚠ @brief Print schema tree in the specified format into a memory block.
It is up to caller to free the returned string by free(). lys_print_module ⚠ @brief Schema module printer. lys_print_node ⚠ @brief Schema node printer. lys_print_path ⚠ @brief Print schema tree in the specified format into a file. lys_print_submodule ⚠ @brief Schema submodule printer. lys_search_localfile ⚠ @brief Search for the schema file in the specified searchpaths. lys_set_implemented ⚠ @brief Make the specific module implemented. lysc_data_node ⚠ @brief Get nearest @p schema parent (including the node itself) that can be instantiated in data. lysc_get_ext_plugin ⚠ @brief Get an extension plugin. lysc_get_type_plugin ⚠ @brief Get a type plugin. lysc_has_when ⚠ @brief Check whether the schema node data instance existence depends on any when conditions.
This node and any direct parent choice and case schema nodes are also examined for when conditions. lysc_iffeature_value ⚠ @brief Get how the if-feature statement currently evaluates. lysc_module_dfs_full ⚠ @brief DFS traversal of all the schema nodes in a module including RPCs and notifications. lysc_node_actions ⚠ @brief Get the actions/RPCs linked list of the given (compiled) schema node.
Decides the node’s type and in case it has a actions/RPCs array, returns it.
@param[in] node Node to examine.
@return The node’s actions/RPCs linked list if any, NULL otherwise. lysc_node_child ⚠ @brief Get the children linked list of the given (compiled) schema node. lysc_node_lref_backlinks ⚠ @brief Get all the leafref (or union with leafrefs) nodes that target a specific node. lysc_node_lref_target ⚠ @brief Get the target node of a leafref node. Function ::lysc_node_lref_targets() should be used instead
to get all the leafref targets even for a union node. lysc_node_lref_targets ⚠ @brief Get the target node(s) of a leafref node or union node with leafrefs. lysc_node_musts ⚠ @brief Get the must statements list if present in the @p node lysc_node_notifs ⚠ @brief Get the Notifications linked list of the given (compiled) schema node.
Decides the node’s type and in case it has a Notifications array, returns it.
@param[in] node Node to examine.
@return The node’s Notifications linked list if any, NULL otherwise. lysc_node_when ⚠ @brief Get the when statements list if present in the @p node lysc_owner_module ⚠ @brief Get the owner module of the schema node. It is the module of the top-level node. Generally,
in case of augments it is the target module, recursively, otherwise it is the module where the node is defined. lysc_path ⚠ @brief Generate path of the given node in the requested format. lysc_tree_dfs_full ⚠ @brief DFS traversal of all the schema nodes in a (sub)tree including any actions and nested notifications. lysp_feature_next ⚠ @brief Get the next feature in the module or submodules. lysp_node_actions ⚠ @brief Get the actions/RPCs linked list of the given (parsed) schema node.
Decides the node’s type and in case it has a actions/RPCs array, returns it.
@param[in] node Node to examine.
@return The node’s actions/RPCs linked list if any, NULL otherwise. lysp_node_child ⚠ @brief Get the children linked list of the given (parsed) schema node.
Decides the node’s type and in case it has a children list, returns it.
@param[in] node Node to examine.
@return The node’s children linked list if any, NULL otherwise. lysp_node_groupings ⚠ @brief Get the groupings linked list of the given (parsed) schema node.
Decides the node’s type and in case it has a groupings array, returns it.
@param[in] node Node to examine.
@return The node’s groupings linked list if any, NULL otherwise. lysp_node_notifs ⚠ @brief Get the Notifications linked list of the given (parsed) schema node.
Decides the node’s type and in case it has a Notifications array, returns it.
@param[in] node Node to examine.
@return The node’s Notifications linked list if any, NULL otherwise. lysp_node_typedefs ⚠ @brief Get the typedefs sized array of the given (parsed) schema node.
Decides the node’s type and in case it has a typedefs array, returns it.
@param[in] node Node to examine.
@return The node’s typedefs sized array if any, NULL otherwise. lyxp_get_expr ⚠ @brief Getter for original XPath expression from a parsed expression. lyxp_vars_free ⚠ @brief Free the XPath variables. lyxp_vars_set ⚠ @brief Set a new XPath variable to @p vars. FILE _IO_lock_t __off64_t __off_t __syscall_slong_t __time_t in_addr_t ly_bool @brief Type to indicate boolean value. ly_ext_data_clb @brief Callback for getting arbitrary run-time data required by an extension instance. ly_log_clb @brief Logger callback. ly_module_imp_clb @brief Callback for retrieving missing included or imported modules in a custom way. ly_module_imp_data_free_clb @brief Callback for freeing returned module data in #ly_module_imp_clb. ly_write_clb @brief Generic write callback for data printed by libyang. lyd_diff_cb @brief Callback for diff nodes. lyd_merge_cb @brief Callback for matching merge nodes. lyplg_ext_compile_clb @brief Callback to compile extension from the lysp_ext_instance to the lysc_ext_instance. The later structure is generally prepared
and only the extension specific data are supposed to be added (if any). lyplg_ext_compile_free_clb @brief Callback to free the extension-specific data created by its compilation. lyplg_ext_compiled_print_clb @brief Callback to print (serialize) the custom compiled structure and substmts array storage. lyplg_ext_compiled_size_clb @brief Callback to return the size of the custom compiled structure and substmts array. If there are none, do not
define this callback. lyplg_ext_data_snode_clb @brief Callback for getting a schema node for new YANG instance data described by an extension instance. lyplg_ext_data_validate_clb @brief Callback for validating parsed YANG instance data described by an extension instance. lyplg_ext_node_xpath_clb @brief Callback for getting the first child data node of an XPath document root of the extension instance. lyplg_ext_parse_clb @brief Callback for parsing extension instance substatements. lyplg_ext_parse_free_clb @brief Callback to free the extension-specific data created by its parsing. lyplg_ext_snode_xpath_clb @brief Callback for getting the first child schema node of an XPath document root of the extension instance. lyplg_ext_sprinter_info_clb @brief Callback to print the compiled extension instance’s private data in the INFO format. lysc_dfs_clb @brief Callback to be called for every schema node in a DFS traversal. time_t in6_addr__bindgen_ty_1 ly_opaq_name__bindgen_ty_1 ly_set__bindgen_ty_1 lyd_node_any__bindgen_ty_1 lyd_node_inner__bindgen_ty_1 lyd_node_opaq__bindgen_ty_1 lyd_node_term__bindgen_ty_1 lyd_value__bindgen_ty_1 lysc_node_action__bindgen_ty_1 lysc_node_action_inout__bindgen_ty_1 lysc_node_anydata__bindgen_ty_1 lysc_node_case__bindgen_ty_1 lysc_node_choice__bindgen_ty_1 lysc_node_container__bindgen_ty_1 lysc_node_leaf__bindgen_ty_1 lysc_node_leaflist__bindgen_ty_1 lysc_node_list__bindgen_ty_1 lysc_node_notif__bindgen_ty_1 lysc_range_lysc_range_part__bindgen_ty_1 lysc_range_lysc_range_part__bindgen_ty_2 lysc_type_bitenum_item__bindgen_ty_1 lysp_node_action__bindgen_ty_1 lysp_node_action_inout__bindgen_ty_1 lysp_node_anydata__bindgen_ty_1 lysp_node_augment__bindgen_ty_1 lysp_node_case__bindgen_ty_1 lysp_node_choice__bindgen_ty_1 lysp_node_container__bindgen_ty_1 lysp_node_grp__bindgen_ty_1 lysp_node_leaf__bindgen_ty_1 lysp_node_leaflist__bindgen_ty_1 lysp_node_list__bindgen_ty_1 lysp_node_notif__bindgen_ty_1 lysp_node_uses__bindgen_ty_1