Constants
- LYD_
PATH_ STD - < Generic data path used for logging, node searching (::lyd_find_xpath(), ::lys_find_path()) as well as creating new nodes (::lyd_new_path(), ::lyd_new_path2()).
- LYD_
PATH_ STD_ NO_ LAST_ PRED - < Similar to ::LYD_PATH_STD except there is never a predicate on the last node. While it can be used to search for nodes, do not use it to create new data nodes (lists).
Type Aliases
- Type
- @brief Types of the different data paths.