Constants
- LY_
LLDBG - < Print all messages including some development debug messages (be careful, without subsequently calling ::ly_log_dbg_groups() no debug messages will be printed!).
- LY_
LLERR - < Print only error messages.
- LY_
LLVRB - < Besides errors and warnings, print some other verbose messages.
- LY_
LLWRN - < Print error and warning messages, default value.
Type Aliases
- Type
- @typedef LY_LOG_LEVEL @brief Verbosity levels of the libyang logger.