pub unsafe extern "C" fn ly_ctx_get_module_iter(
ctx: *const ly_ctx,
index: *mut u32,
) -> *mut lys_moduleExpand description
@brief Iterate over all modules in the given context.
@param[in] ctx Context with the modules. @param[in,out] index Index of the next module to get. Value of 0 starts from the beginning. The value is updated with each call, so to iterate over all modules the same variable is supposed to be used in all calls starting with value 0. @return Next context module, NULL if the last was already returned.