pub unsafe extern "C" fn ly_ctx_get_module_ns(
ctx: *const ly_ctx,
ns: *const c_char,
revision: *const c_char,
) -> *mut lys_moduleExpand description
@brief Get YANG module of the given namespace and revision.
@param[in] ctx Context to work in. @param[in] ns Namespace of the YANG module to get. @param[in] revision Requested revision date of the YANG module to get. If not specified, the schema with no revision is returned, if it is present in the context. @return Pointer to the YANG module, NULL if no schema in the context follows the namespace and revision requirements.