pub unsafe extern "C" fn ly_ctx_get_yanglib_data(
ctx: *const ly_ctx,
root: *mut *mut lyd_node,
content_id_format: *const c_char,
...
) -> TypeExpand description
@brief Get data of the internal ietf-yang-library module with information about all the loaded modules. ietf-yang-library module must be loaded.
Note that “/ietf-yang-library:yang-library/datastore” list instances are not created and should be appended by the caller. There is a single “/ietf-yang-library:yang-library/schema” instance created with the key value “complete”.
If the data identifier can be limited to the existence and changes of this context, the following last 2 parameters can be used:
“%u” as @p content_id_format and ::ly_ctx_get_change_count() as its parameter; “%u” as @p content_id_format and ::ly_ctx_get_modules_hash() as its parameter.
@param[in] ctx Context with the modules. @param[out] root Generated yang-library data. @param[in] content_id_format Format string (printf-like) for the yang-library data identifier, which is the “content_id” node in the 2019-01-04 revision of ietf-yang-library. @param[in] … Parameters for @p content_id_format. @return LY_ERR value