pub unsafe extern "C" fn ly_ctx_set_ext_data_clb(
ctx: *const ly_ctx,
clb: ly_ext_data_clb,
user_data: *mut c_void,
) -> ly_ext_data_clbExpand description
@brief Set callback providing run-time extension instance data. The expected data depend on the extension. Data expected by internal extensions:
- ietf-yang-schema-mount:mount-point (struct lyd_node **ext_data)\n
Operational data tree with at least
ietf-yang-librarydata describing the mounted schema andietf-yang-schema-mountvalidated data describing the specific mount point (ref).
@param[in] ctx Context that will use this callback. @param[in] clb Callback responsible for returning the extension instance data. @param[in] user_data Arbitrary data that will always be passed to the callback @p clb.