pub unsafe extern "C" fn ly_ctx_set_module_imp_clb(
ctx: *mut ly_ctx,
clb: ly_module_imp_clb,
user_data: *mut c_void,
)Expand description
@brief Set missing include or import module callback. It is meant to be used when the modules are not locally available (such as when downloading modules from a NETCONF server), it should not be required in other cases.
@param[in] ctx Context that will use this callback. @param[in] clb Callback responsible for returning the missing module. @param[in] user_data Arbitrary data that will always be passed to the callback @p clb.