pub unsafe extern "C" fn ly_ctx_set_options(
ctx: *mut ly_ctx,
option: u32,
) -> TypeExpand description
@brief Set some of the context’s options, see @ref contextoptions. @param[in] ctx Context to be modified. @param[in] option Combination of the context’s options to be set, see @ref contextoptions. If there is to be a change to ::LY_CTX_SET_PRIV_PARSED, the context will be recompiled and all ::lysc_node.priv in the modules will be overwritten, see ::LY_CTX_SET_PRIV_PARSED. @return LY_ERR value.