pub unsafe extern "C" fn ly_in_memory(
in_: *mut ly_in,
str_: *const c_char,
) -> *const c_charExpand description
@brief Get or change memory where the data are read from.
@param[in] in Input handler. @param[in] str String containing the data to read. The input data are expected to be NULL-terminated. Note that in case the destroy argument of ::ly_in_free() is used, the input string is passed to free(), so if it is really a static string, do not use the destroy argument! @return Previous starting address to read data from. Note that the caller is responsible to free the data in case of changing string pointer @p str.