pub unsafe extern "C" fn ly_in_reset(in_: *mut ly_in) -> TypeExpand description
@brief Reset the input medium to read from its beginning, so the following parser function will read from the object’s beginning.
Note that in case the underlying output is not seekable (stream referring a pipe/FIFO/socket or the callback output type), nothing actually happens despite the function succeeds. Also note that the medium is not returned to the state it was when the handler was created. For example, file is seeked into the offset zero, not to the offset where it was opened when ::ly_in_new_file() was called.
@param[in] in Input handler. @return LY_SUCCESS in case of success @return LY_ESYS in case of failure