pub unsafe extern "C" fn ly_in_skip(
in_: *mut ly_in,
count: usize,
) -> TypeExpand description
@brief Just skip bytes in an input.
Does not count new lines, which is expected from the caller who has better idea about the content of the skipped data and can better optimize counting.
@param[in] in Input structure. @param[in] count Number of bytes to skip. @return LY_SUCCESS on success, @return LY_EDENIED on EOF.