pub unsafe extern "C" fn ly_last_logmsg() -> *const c_charExpand description
@brief Get the last (thread-specific) full logged error message.
This function is useful for getting errors from functions that do not have any context accessible and includes any additional information such as the path or line where the error occurred.
@return Last generated error message.