pub unsafe extern "C" fn ly_log_options(opts: u32) -> u32Expand description
@brief Set global logger options. Default is #LY_LOLOG | #LY_LOSTORE_LAST.
To get the current value, the function must be called twice resetting the level by the received value.
@param[in] opts Bitfield of @ref logopts. @return Previous logger options.