pub unsafe extern "C" fn ly_out_filepath(
out: *mut ly_out,
filepath: *const c_char,
) -> *const c_charExpand description
@brief Get or change the filepath of the file where the printer prints the data.
Note that in case of changing the filepath, the current file is closed and a new one is created/opened instead of renaming the previous file. Also note that the previous filepath string is returned only in case of not changing it’s value.
@param[in] out Printer handler. @param[in] filepath Optional new filepath for the handler. If and only if NULL, the current filepath string is returned. @return Previous filepath string in case the @p filepath argument is NULL. @return NULL if changing filepath succeeds and ((void *)-1) otherwise.