pub unsafe extern "C" fn ly_print(
out: *mut ly_out,
format: *const c_char,
...
) -> TypeExpand description
@brief Generic printer of the given format string into the specified output.
Alternatively, ::ly_write() can be used.
@param[in] out Output specification. @param[in] format Format string to be printed. @return LY_ERR value, get number of the printed bytes using ::ly_out_printed.