pub unsafe extern "C" fn ly_time_str2time(
value: *const c_char,
time: *mut time_t,
fractions_s: *mut *mut c_char,
) -> TypeExpand description
@brief Convert date-and-time from string to UNIX timestamp and fractions of a second.
@param[in] value Valid string date-and-time value, the string may continue after the value (be longer). @param[out] time UNIX timestamp. @param[out] fractions_s Optional fractions of a second, set to NULL if none. @return LY_ERR value.