pub unsafe extern "C" fn lyd_first_sibling(
node: *const lyd_node,
) -> *mut lyd_nodeExpand description
@brief Get the first sibling of the given node.
@param[in] node Node which first sibling is going to be the result. @return The first sibling of the given node or the node itself if it is the first child of the parent.