pub unsafe extern "C" fn lyd_new_term(
parent: *mut lyd_node,
module: *const lys_module,
name: *const c_char,
value: *const c_char,
options: u32,
node: *mut *mut lyd_node,
) -> TypeExpand description
@brief Create a new term node in the data tree.
@param[in] parent Parent node for the node being created. NULL in case of creating a top level element. @param[in] module Module of the node being created. If NULL, @p parent module will be used. @param[in] name Schema node name of the new data node. The node can be #LYS_LEAF or #LYS_LEAFLIST. @param[in] value Value of the node in JSON format unless changed by @p options. @param[in] options Bitmask of options, see @ref newvaloptions. @param[out] node Optional created node. @return LY_ERR value.