pub unsafe extern "C" fn lyd_path(
node: *const lyd_node,
pathtype: Type,
buffer: *mut c_char,
buflen: usize,
) -> *mut c_charExpand description
@brief Generate path of the given node in the requested format.
The path is constructed based on the parent node(s) of this node. When run on a node which is disconnected
from its parent(s), this function might yield unexpected results such as /example:b instead of the expected
/example:a/b.
@param[in] node Data path of this node will be generated. @param[in] pathtype Format of the path to generate. @param[in,out] buffer Prepared buffer of the @p buflen length to store the generated path. If NULL, memory for the complete path is allocated. @param[in] buflen Size of the provided @p buffer. @return NULL in case of memory allocation error, path of the node otherwise. In case the @p buffer is NULL, the returned string is dynamically allocated and caller is responsible to free it.