pub unsafe extern "C" fn lyd_validate_op(
op_tree: *mut lyd_node,
dep_tree: *const lyd_node,
data_type: Type,
diff: *mut *mut lyd_node,
) -> TypeExpand description
@brief Validate an RPC/action request, reply, or notification. Only the operation data tree (input/output/notif) is validate, any parents are ignored.
@param[in,out] op_tree Operation tree with any parents. It can point to the operation itself or any of its parents, only the operation subtree is actually validated. @param[in] dep_tree Tree to be used for validating references from the operation subtree. @param[in] data_type Operation type to validate (only YANG operations are accepted, @ref datatype). @param[out] diff Optional diff with any changes made by the validation. @return LY_SUCCESS on success. @return LY_ERR error on error.