pub unsafe extern "C" fn lyplg_ext_compiled_node_augments(
ctx: *mut lysc_ctx,
ext: *mut lysc_ext_instance,
node: *mut lysc_node,
) -> TypeExpand description
@brief Compile augments for a specific node in an extension instance.
May be useful for cases when there are virtual nodes that cannot be compiled using ::lyplg_ext_compile_extension_instance().
@param[in] ctx Compile context. @param[in] ext Compiled extension instance. @param[in,out] node Compiled schema node to apply any matching augments for. @return LY_ERR value.