pub unsafe extern "C" fn lyplg_ext_get_data(
ctx: *const ly_ctx,
ext: *const lysc_ext_instance,
parent: *const lyd_node,
ext_data: *mut *mut c_void,
ext_data_free: *mut ly_bool,
) -> TypeExpand description
@brief Get specific run-time extension instance data from a callback set by ::ly_ctx_set_ext_data_clb().
@param[in] ctx Context with the callback. @param[in] ext Compiled extension instance. @param[in] parent Data parent node instance of a schema node with @p ext instance. @param[out] ext_data Provided extension instance data. @param[out] ext_data_free Whether the extension instance should free @p ext_data or not. @return LY_SUCCESS on success. @return LY_ERR on error.