pub unsafe extern "C" fn lyplg_ext_parse_extension_instance(
pctx: *mut lysp_ctx,
ext: *mut lysp_ext_instance,
) -> TypeExpand description
@brief Parse substatements of an extension instance.
Uses standard libyang schema compiler to transform YANG statements into the parsed schema structures. The plugins are supposed to use this function when the extension instance’s substatements can be parsed in a standard way.
@param[in] pctx Parse context. @param[in,out] ext Parsed extension instance with the prepared ::lysp_ext_instance.substmts array, which will be updated by storing the parsed data. @return LY_SUCCESS on success. @return LY_ERR error on error.