pub unsafe extern "C" fn lyplg_ext_schema_mount_create_context(
ext: *const lysc_ext_instance,
parent: *const lyd_node,
ctx: *mut *mut ly_ctx,
) -> TypeExpand description
@brief Allocate a new context for a particular instance of the yangmnt:mount-point extension. Caller is responsible for freeing the created context.
@param[in] ext Compiled extension instance. @param[in] parent Data parent node instance of a schema node with @p ext instance. @param[out] ctx Context with modules loaded from the list found in the extension data. @return LY_ERR value.