pub unsafe extern "C" fn lys_feature_value(
module: *const lys_module,
feature: *const c_char,
) -> TypeExpand description
@brief Get the current real status of the specified feature in the module.
If the feature is enabled, but some of its if-features are false, the feature is considered disabled.
@param[in] module Module where the feature is defined. @param[in] feature Name of the feature to inspect. @return LY_SUCCESS if the feature is enabled, @return LY_ENOT if the feature is disabled, @return LY_ENOTFOUND if the feature was not found.