pub unsafe extern "C" fn lys_parse(
ctx: *mut ly_ctx,
in_: *mut ly_in,
format: Type,
features: *mut *const c_char,
module: *mut *mut lys_module,
) -> TypeExpand description
@brief Load a schema into the specified context.
@param[in] ctx libyang context to use. @param[in] in Input handle to provide the dumped module in the specified format. @param[in] format Format of the schema to parse. Can be 0 to try to detect format from the input handler. @param[in] features Array of features to enable ended with NULL. If NULL, no features are enabled. @param[out] module Optional parsed module. @return LY_ERR value.