pub unsafe extern "C" fn lys_parse_fd(
ctx: *mut ly_ctx,
fd: c_int,
format: Type,
module: *mut *mut lys_module,
) -> TypeExpand description
@brief Read a schema from file descriptor into the specified context.
@note Current implementation supports only reading data from standard (disk) file, not from sockets, pipes, etc.
This function is considered for a simple use, if you have a complex use-case, consider use of ::lys_parse() with a standalone input handler.
@param[in] ctx libyang context to use. @param[in] fd File descriptor of a regular file (e.g. sockets are not supported) containing the schema in the specified format. @param[in] format Format of the schema to parse. @param[out] module Optional parsed module. @return LY_ERR value.