pub unsafe extern "C" fn lys_parse_path(
ctx: *mut ly_ctx,
path: *const c_char,
format: Type,
module: *mut *mut lys_module,
) -> TypeExpand description
@brief Load a schema into the specified context from a file.
This function is considered for a simple use, if you have a complex use-case, consider use of ::lys_parse() with a standalone input handler.
@param[in] ctx libyang context to use. @param[in] path Path to the file with the module in the specified format. @param[in] format Format of the schema to parse. @param[out] module Optional parsed module. @return LY_ERR value.