pub unsafe extern "C" fn lys_print_module(
out: *mut ly_out,
module: *const lys_module,
format: Type,
line_length: usize,
options: u32,
) -> TypeExpand description
@brief Schema module printer.
@param[in] out Printer handler for a specific output. Use ly_out_*() functions to create and free the handler. @param[in] module Main module with the parsed schema to print. @param[in] format Output format. @param[in] line_length Maximum characters to be printed on a line, 0 for unlimited. Only for #LYS_OUT_TREE printer. @param[in] options Schema output options (see @ref schemaprinterflags). @return LY_ERR value.