pub unsafe extern "C" fn lysc_node_lref_targets(
node: *const lysc_node,
set: *mut *mut ly_set,
) -> TypeExpand description
@brief Get the target node(s) of a leafref node or union node with leafrefs.
@param[in] node Term node to use. @param[out] set Set with all the leafref targets, may be empty if the node is a different type or the targets are not found. @return LY_SUCCESS on success. @return LY_ERR value on error.