pub unsafe extern "C" fn lysc_node_notifs(
node: *const lysc_node,
) -> *const lysc_node_notifExpand description
@brief Get the Notifications linked list of the given (compiled) schema node. Decides the node’s type and in case it has a Notifications array, returns it. @param[in] node Node to examine. @return The node’s Notifications linked list if any, NULL otherwise.