pub unsafe extern "C" fn lysc_node_when(
node: *const lysc_node,
) -> *mut *mut lysc_whenExpand description
@brief Get the when statements list if present in the @p node
@param[in] node Node to examine. @return Pointer to the list of pointers to when statements ([sized array](@ref sizedarrays)) @return NULL if there is no when statement in the node, no matter if it is not even allowed or just present