pub unsafe extern "C" fn lysp_feature_next(
last: *const lysp_feature,
pmod: *const lysp_module,
idx: *mut u32,
) -> *mut lysp_featureExpand description
@brief Get the next feature in the module or submodules.
@param[in] last Last returned feature. @param[in] pmod Parsed module and submodules whose features to iterate over. @param[in,out] idx Submodule index, set to 0 on first call. @return Next found feature, NULL if the last has already been returned.