pub type Type = c_uint;
@brief List of YANG statements
Their description mentions what types are stored for each statement. Note that extension instance storage always stores a pointer to the type, not the type itself.