Constants
- LYD_
TYPE_ DATA_ YANG - < generic YANG instance data
- LYD_
TYPE_ NOTIF_ NETCONF - < complete NETCONF notification message as defined for notification
- LYD_
TYPE_ NOTIF_ RESTCONF - < RESTCONF JSON notification data (ref), to parse a notification in XML, use ::LYD_TYPE_NOTIF_NETCONF
- LYD_
TYPE_ NOTIF_ YANG - < instance of a YANG notification, including all parents in case of a nested one
- LYD_
TYPE_ REPLY_ NETCONF - < complete NETCONF RPC reply as defined for RPC and action
- LYD_
TYPE_ REPLY_ RESTCONF - < message-body of a RESTCONF operation output parameters (ref)
- LYD_
TYPE_ REPLY_ YANG - < instance of a YANG RPC/action reply with only “output” data children, including all parents in case of an action
- LYD_
TYPE_ RPC_ NETCONF - < complete NETCONF RPC invocation as defined for RPC and action
- LYD_
TYPE_ RPC_ RESTCONF - < message-body of a RESTCONF operation input parameters (ref)
- LYD_
TYPE_ RPC_ YANG - < instance of a YANG RPC/action request with only “input” data children, including all parents and optional top-level “action” element in case of an action
Type Aliases
- Type
- @ingroup datatree @defgroup datatype Data operation type