#[repr(C)]pub struct ly_set {
pub size: u32,
pub count: u32,
pub __bindgen_anon_1: ly_set__bindgen_ty_1,
}Expand description
@brief Structure to hold a set of (not necessary somehow connected) objects. Usually used for lyd_node, ::lysp_node or ::lysc_node objects, but it is not limited to them. Caller is supposed to not mix the type of objects added to the set and according to its knowledge about the set content, it can access objects via the members of the set union.
Until ::ly_set_rm() or ::ly_set_rm_index() is used, the set keeps the order of the inserted items as they were added into the set, so the first added item is on array index 0.
To free the structure, use ::ly_set_free() function, to manipulate with the structure, use other ly_set_* functions.
Fields
size: u32< allocated size of the set array
count: u32< number of elements in (used size of) the set array
__bindgen_anon_1: ly_set__bindgen_ty_1Trait Implementations