#[repr(C)]pub struct lyd_value {
pub _canonical: *const c_char,
pub realtype: *const lysc_type,
pub __bindgen_anon_1: lyd_value__bindgen_ty_1,
}Expand description
@brief YANG data representation
Fields
_canonical: *const c_char< Should never be accessed directly, instead ::lyd_get_value() and ::lyd_get_meta_value() should be used. Serves as a cache for the canonical value or the JSON representation if no canonical value is defined.
realtype: *const lysc_type< pointer to the real type of the data stored in the value structure. This type can differ from the type in the schema node of the data node since the type’s store plugin can use other types/plugins for storing data. Speaking about built-in types, this is the case of leafref which stores data as its target type. In contrast, union type also uses its subtype’s callbacks, but inside an internal data stored in subvalue member of ::lyd_value structure, so here is the pointer to the union type. In general, this type is used to get free callback for this lyd_value structure, so it must reflect the type used to store data directly in the same lyd_value instance.
__bindgen_anon_1: lyd_value__bindgen_ty_1