#[repr(C)]pub struct lyd_value_union {
pub value: lyd_value,
pub original: *mut c_void,
pub orig_size_bits: u64,
pub hints: u32,
pub format: Type,
pub prefix_data: *mut c_void,
pub ctx_node: *const lysc_node,
}Expand description
@brief Special lyd_value structure for built-in union values.
Represents data with multiple types (union). The ::lyd_value_union.value contains representation according to one of the union’s types. The ::lyd_value_union.prefix_data provides (possible) mappings from prefixes in the original value to YANG modules. These prefixes are necessary to parse original value to the union’s subtypes.
Fields
value: lyd_value< representation of the value according to the selected union’s subtype (stored as ::lyd_value.realtype here)
original: *mut c_void< Original value.
orig_size_bits: u64< Original value size in bits.
hints: u32< [Value hints](@ref lydvalhints) from the parser
format: Type< Prefix format of the value. However, this information is also used to decide whether a value is valid for the specific format or not on later validations (instance-identifier in XML looks different than in JSON).
prefix_data: *mut c_void< Format-specific data for prefix resolution (see ly_resolve_prefix())
ctx_node: *const lysc_node< Context schema node.