#[repr(C)]pub struct lyplg_ext_record {
pub module: *const c_char,
pub revision: *const c_char,
pub name: *const c_char,
pub plugin: lyplg_ext,
}Fields
module: *const c_char< name of the module where the extension is defined
revision: *const c_char< optional module revision - if not specified, the plugin applies to any revision, which is not an optimal approach due to a possible future revisions of the module. Instead, there should be defined multiple items in the plugins list, each with the different revision, but all with the same pointer to the plugin functions. The only valid use case for the NULL revision is the case the module has no revision.
name: *const c_char< YANG name of the extension
plugin: lyplg_ext< data to utilize plugin implementation